# -*- coding: utf-8 -*-
import base64
import json
import os
import re
import time

import requests
import rsa

from dailycheckin import CheckIn


class Cloud189(CheckIn):
    name = "天翼云盘"

    def __init__(self, check_item: dict):
        self.check_item = check_item
        self.b64map = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/"

    @staticmethod
    def int2char(a):
        return list("0123456789abcdefghijklmnopqrstuvwxyz")[a]

    def b64tohex(self, a):
        d = ""
        e = 0
        c = 0
        for i in range(len(a)):
            if list(a)[i] != "=":
                v = self.b64map.index(list(a)[i])
                if 0 == e:
                    e = 1
                    d += self.int2char(v >> 2)
                    c = 3 & v
                elif 1 == e:
                    e = 2
                    d += self.int2char(c << 2 | v >> 4)
                    c = 15 & v
                elif 2 == e:
                    e = 3
                    d += self.int2char(c)
                    d += self.int2char(v >> 2)
                    c = 3 & v
                else:
                    e = 0
                    d += self.int2char(c << 2 | v >> 4)
                    d += self.int2char(15 & v)
        if e == 1:
            d += self.int2char(c << 2)
        return d

    def rsa_encode(self, j_rsakey, string):
        rsa_key = f"-----BEGIN PUBLIC KEY-----\n{j_rsakey}\n-----END PUBLIC KEY-----"
        pubkey = rsa.PublicKey.load_pkcs1_openssl_pem(rsa_key.encode())
        result = self.b64tohex((base64.b64encode(rsa.encrypt(f"{string}".encode(), pubkey))).decode())
        return result

    def login(self, session, username, password):
        url = "https://cloud.189.cn/api/portal/loginUrl.action?redirectURL=https://cloud.189.cn/web/redirect.html"
        r = session.get(url=url)
        captchatoken = re.findall(r"captchaToken' value='(.+?)'", r.text)[0]
        lt = re.findall(r'lt = "(.+?)"', r.text)[0]
        returnurl = re.findall(r"returnUrl = '(.+?)'", r.text)[0]
        paramid = re.findall(r'paramId = "(.+?)"', r.text)[0]
        j_rsakey = re.findall(r'j_rsaKey" value="(\S+)"', r.text, re.M)[0]
        session.headers.update({"lt": lt})

        username = self.rsa_encode(j_rsakey, username)
        password = self.rsa_encode(j_rsakey, password)
        url = "https://open.e.189.cn/api/logbox/oauth2/loginSubmit.do"
        headers = {
            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:74.0) Gecko/20100101 Firefox/76.0",
            "Referer": "https://open.e.189.cn/",
        }
        data = {
            "appKey": "cloud",
            "accountType": "01",
            "userName": f"{{RSA}}{username}",
            "password": f"{{RSA}}{password}",
            "validateCode": "",
            "captchaToken": captchatoken,
            "returnUrl": returnurl,
            "mailSuffix": "@189.cn",
            "paramId": paramid,
        }
        r = session.post(url, data=data, headers=headers, timeout=5)
        if r.json()["result"] == 0:
            redirect_url = r.json()["toUrl"]
            session.get(url=redirect_url)
            return True
        else:
            return {"name": "登陆信息", "value": r.json()["msg"]}

    @staticmethod
    def sign(session):
        rand = str(round(time.time() * 1000))
        surl = f"https://api.cloud.189.cn/mkt/userSign.action?rand={rand}&clientType=TELEANDROID&version=8.6.3&model=SM-G930K"
        url = "https://m.cloud.189.cn/v2/drawPrizeMarketDetails.action?taskId=TASK_SIGNIN&activityId=ACT_SIGNIN"
        url2 = "https://m.cloud.189.cn/v2/drawPrizeMarketDetails.action?taskId=TASK_SIGNIN_PHOTOS&activityId=ACT_SIGNIN"
        headers = {
            "User-Agent": "Mozilla/5.0 (Linux; Android 5.1.1; SM-G930K Build/NRD90M; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/74.0.3729.136 Mobile Safari/537.36 Ecloud/8.6.3 Android/22 clientId/355325117317828 clientModel/SM-G930K imsi/460071114317824 clientChannelId/qq proVersion/1.0.6",
            "Referer": "https://m.cloud.189.cn/zhuanti/2016/sign/index.jsp?albumBackupOpened=1",
            "Host": "m.cloud.189.cn",
            "Accept-Encoding": "gzip, deflate",
        }
        response = session.get(url=surl, headers=headers)
        netdiskbonus = response.json().get("netdiskBonus")
        msg = []
        if response.json().get("isSign") == "false":
            msg.append({"name": "签到结果", "value": f"未签到，签到获得 {netdiskbonus}M 空间"})
        else:
            msg.append({"name": "签到结果", "value": f"已经签到过了，签到获得 {netdiskbonus}M 空间"})
        response = session.get(url=url, headers=headers)
        if "errorCode" in response.text:
            if response.json().get("errorCode") == "User_Not_Chance":
                description = "没有抽奖机会了"
            else:
                description = response.json().get("errorCode")
            msg.append({"name": "第一次抽", "value": description})
        else:
            description = response.json().get("description", "")
            if description in ["1", 1]:
                description = "50M空间"
            msg.append({"name": "第一次抽", "value": f"获得{description}"})
        response = session.get(url=url2, headers=headers)
        if "errorCode" in response.text:
            if response.json().get("errorCode") == "User_Not_Chance":
                description = "没有抽奖机会了"
            else:
                description = response.json().get("errorCode")
            msg.append({"name": "第二次抽", "value": description})
        else:
            description = response.json().get("description", "")
            if description in ["1", 1]:
                description = "50M空间"
            msg.append({"name": "第二次抽", "value": f"获得{description}"})
        return msg

    def main(self):
        cloud189_phone = self.check_item.get("phone")
        cloud189_password = self.check_item.get("password")
        session = requests.Session()
        flag = self.login(session=session, username=cloud189_phone, password=cloud189_password)
        if flag is True:
            sign_msg = self.sign(session=session)
        else:
            sign_msg = flag
        msg = [{"name": "帐号信息", "value": cloud189_phone}] + sign_msg
        msg = "\n".join([f"{one.get('name')}: {one.get('value')}" for one in msg])
        return msg


if __name__ == "__main__":
    with open(os.path.join(os.path.dirname(os.path.dirname(__file__)), "config.json"), "r", encoding="utf-8") as f:
        datas = json.loads(f.read())
    _check_item = datas.get("CLOUD189", [])[0]
    print(Cloud189(check_item=_check_item).main())



# -*- coding: utf-8 -*-
import json
import os

from dailycheckin import CheckIn


def checkin_map():
    result = {}
    for cls in CheckIn.__subclasses__():
        check_name = cls.__name__.upper()
        if check_name:
            result[check_name] = (cls.name, cls)
    return result


checkin_map = checkin_map()

notice_map = {
    "BARK_URL": "",
    "COOLPUSHEMAIL": "",
    "COOLPUSHQQ": "",
    "COOLPUSHSKEY": "",
    "COOLPUSHWX": "",
    "DINGTALK_ACCESS_TOKEN": "",
    "DINGTALK_SECRET": "",
    "FSKEY": "",
    "PUSHPLUS_TOKEN": "",
    "PUSHPLUS_TOPIC": "",
    "QMSG_KEY": "",
    "QMSG_TYPE": "",
    "QYWX_AGENTID": "",
    "QYWX_CORPID": "",
    "QYWX_CORPSECRET": "",
    "QYWX_KEY": "",
    "QYWX_TOUSER": "",
    "QYWX_MEDIA_ID": "",
    "SCKEY": "",
    "SENDKEY": "",
    "TG_API_HOST": "",
    "TG_BOT_TOKEN": "",
    "TG_PROXY": "",
    "TG_USER_ID": "",
    "MERGE_PUSH": ""
}


def env2list(key):
    try:
        value = json.loads(os.getenv(key, []).strip()) if os.getenv(key) else []
        if isinstance(value, list):
            value = value
        else:
            value = []
    except Exception as e:
        print(e)
        value = []
    return value


def env2str(key):
    try:
        value = os.getenv(key, "") if os.getenv(key) else ""
        if isinstance(value, str):
            value = value.strip()
        elif isinstance(value, bool):
            value = value
        else:
            value = None
    except Exception as e:
        print(e)
        value = None
    return value


def get_checkin_info(data):
    result = {}
    if isinstance(data, dict):
        for one in checkin_map.keys():
            result[one.lower()] = data.get(one, [])
    else:
        for one in checkin_map.keys():
            result[one.lower()] = env2list(one)
    return result


def get_notice_info(data):
    result = {}
    if isinstance(data, dict):
        for one in notice_map.keys():
            result[one.lower()] = data.get(one, None)
    else:
        for one in notice_map.keys():
            result[one.lower()] = env2str(one)
    return result



# -*- coding: utf-8 -*-
import json
import os

import requests
from requests import utils

from dailycheckin import CheckIn


class Smzdm(CheckIn):
    name = "什么值得买"

    def __init__(self, check_item):
        self.check_item = check_item

    @staticmethod
    def sign(session):
        try:
            current = session.get(url="https://zhiyou.smzdm.com/user/info/jsonp_get_current").json()
            if current["checkin"]["has_checkin"]:
                msg = [
                    {"name": "账号信息", "value": current.get("nickname", "")},
                    {"name": "目前积分", "value": current.get("point", "")},
                    {"name": "当前经验", "value": current.get("exp", "")},
                    {"name": "当前金币", "value": current.get("gold", "")},
                    {"name": "碎银子数", "value": current.get("silver", "")},
                    {"name": "当前威望", "value": current.get("prestige", "")},
                    {"name": "当前等级", "value": current.get("level", "")},
                    {"name": "已经签到", "value": f"{current.get('checkin', {}).get('daily_checkin_num', '')} 天"},
                ]
            else:
                response = session.get(url="https://zhiyou.smzdm.com/user/checkin/jsonp_checkin").json().get("data", {})
                msg = [
                    {"name": "账号信息", "value": current.get("nickname", "")},
                    {"name": "目前积分", "value": current.get("point", "")},
                    {"name": "增加积分", "value": current.get("add_point", "")},
                    {"name": "当前经验", "value": current.get("exp", "")},
                    {"name": "当前金币", "value": current.get("gold", "")},
                    {"name": "当前威望", "value": current.get("prestige", "")},
                    {"name": "当前等级", "value": current.get("rank", "")},
                    {"name": "已经签到", "value": f"{response.get('checkin_num', {})} 天"},
                ]
        except Exception as e:
            msg = [
                {"name": "签到信息", "value": "签到失败"},
                {"name": "错误信息", "value": str(e)},
            ]
        return msg

    def main(self):
        smzdm_cookie = {item.split("=")[0]: item.split("=")[1] for item in self.check_item.get("cookie").split("; ")}
        session = requests.session()
        requests.utils.add_dict_to_cookiejar(session.cookies, smzdm_cookie)
        session.headers.update(
            {
                "Accept": "*/*",
                "Accept-Encoding": "gzip, deflate, br",
                "Accept-Language": "zh-CN,zh;q=0.9",
                "Connection": "keep-alive",
                "Host": "zhiyou.smzdm.com",
                "Referer": "https://www.smzdm.com/",
                "Sec-Fetch-Dest": "script",
                "Sec-Fetch-Mode": "no-cors",
                "Sec-Fetch-Site": "same-site",
                "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/74.0.3729.131 Safari/537.36",
            }
        )
        msg = self.sign(session=session)
        msg = "\n".join([f"{one.get('name')}: {one.get('value')}" for one in msg])
        return msg


if __name__ == "__main__":
    with open(os.path.join(os.path.dirname(os.path.dirname(__file__)), "config.json"), "r", encoding="utf-8") as f:
        datas = json.loads(f.read())
    _check_item = datas.get("SMZDM", [])[0]
    print(Smzdm(check_item=_check_item).main())



# -*- coding: utf-8 -*-
import json
import os
import time

import requests

from dailycheckin import CheckIn


class HeyTap(CheckIn):
    name = "欢太商城"

    def __init__(self, check_item):
        self.check_item = check_item

    @staticmethod
    def login(cookie, useragent):
        session = requests.Session()
        headers = {
            "Host": "www.heytap.com",
            "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
            "Content-Type": "application/x-www-form-urlencoded",
            "Connection": "keep-alive",
            "User-Agent": useragent,
            "Accept-Language": "zh-cn",
            "Accept-Encoding": "gzip, deflate, br",
            "cookie": cookie,
        }
        response = session.get(url="https://www.heytap.com/cn/oapi/users/web/member/info", headers=headers)
        response.encoding = "utf-8"
        try:
            result = response.json()
            if result["code"] == 200:
                return session
            else:
                print(f"【登录失败】: {result['errorMessage']}")
        except Exception as e:
            print(f"【登录失败】:{e}")
        return False

    @staticmethod
    def task_center(session, cookie, useragent):
        headers = {
            "Host": "store.oppo.com",
            "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
            "Content-Type": "application/x-www-form-urlencoded",
            "Connection": "keep-alive",
            "User-Agent": useragent,
            "Accept-Language": "zh-cn",
            "Accept-Encoding": "gzip, deflate, br",
            "cookie": cookie,
            "referer": "https://store.oppo.com/cn/app/taskCenter/index",
        }
        response = session.get(url="https://store.oppo.com/cn/oapi/credits/web/credits/show", headers=headers)
        result = response.json()
        return result

    @staticmethod
    def cashing_credits(session, useragent, cookie, info_marking, info_type, info_credits):
        headers = {
            "Host": "store.oppo.com",
            "clientPackage": "com.oppo.store",
            "Accept": "application/json, text/plain, */*",
            "Content-Type": "application/x-www-form-urlencoded",
            "Connection": "keep-alive",
            "User-Agent": useragent,
            "Accept-Language": "zh-cn",
            "Accept-Encoding": "gzip, deflate, br",
            "cookie": cookie,
            "Origin": "https://store.oppo.com",
            "X-Requested-With": "com.oppo.store",
            "referer": "https://store.oppo.com/cn/app/taskCenter/index?us=gerenzhongxin&um=hudongleyuan&uc=renwuzhongxin",
        }

        data = f"marking={info_marking}&type={info_type}&amount={info_credits}"
        res = session.post(
            url="https://store.oppo.com/cn/oapi/credits/web/credits/cashingCredits", data=data, headers=headers
        )
        res = res.json()
        if res["code"] == 200:
            return True
        else:
            return False

    def dayily_sign(self, session, cookie, useragent):
        try:
            dated = time.strftime("%Y-%m-%d")
            headers = {
                "Host": "store.oppo.com",
                "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
                "Content-Type": "application/x-www-form-urlencoded",
                "Connection": "keep-alive",
                "User-Agent": useragent,
                "Accept-Language": "zh-cn",
                "Accept-Encoding": "gzip, deflate, br",
                "cookie": cookie,
                "referer": "https://store.oppo.com/cn/app/taskCenter/index",
            }
            result = self.task_center(session=session, cookie=cookie, useragent=useragent)
            status = result["data"]["userReportInfoForm"]["status"]
            if status == 0:
                res = result["data"]["userReportInfoForm"]["gifts"]
                for data in res:
                    if data["date"] == dated:
                        qd = data
                        if not qd["today"]:
                            data = "amount=" + str(qd["credits"])
                            response = session.post(
                                url="https://store.oppo.com/cn/oapi/credits/web/report/immediately",
                                headers=headers,
                                data=data,
                            )
                            res = response.json()
                            if res["code"] == 200:
                                return {"name": "每日签到成功", "value": res["data"]["message"]}
                            else:
                                return {"name": "每日签到失败", "value": str(res)}
                        else:
                            if len(str(qd["type"])) < 1:
                                data = "amount=" + str(qd["credits"])
                            else:
                                data = (
                                    "amount="
                                    + str(qd["credits"])
                                    + "&type="
                                    + str(qd["type"])
                                    + "&gift="
                                    + str(qd["gift"])
                                )
                            response1 = session.post(
                                url="https://store.oppo.com/cn/oapi/credits/web/report/immediately",
                                headers=headers,
                                data=data,
                            )
                            res1 = response1.json()
                            if res1["code"] == 200:
                                return {"name": "每日签到成功", "value": res1["data"]["message"]}
                            else:
                                return {"name": "每日签到失败", "value": str(res1)}
            else:
                return {"name": "每日签到", "value": "已经签到过了"}
            time.sleep(1)
        except Exception as e:
            return {"name": "每日签到", "value": f"错误，原因为: {e}"}

    def daily_viewgoods(self, session, cookie, useragent):
        try:
            headers = {
                "clientPackage": "com.oppo.store",
                "Host": "msec.opposhop.cn",
                "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
                "Content-Type": "application/x-www-form-urlencoded",
                "Connection": "keep-alive",
                "User-Agent": "okhttp/3.12.12.200sp1",
                "Accept-Encoding": "gzip",
                "cookie": cookie,
            }
            res = self.task_center(session=session, cookie=cookie, useragent=useragent)
            res = res["data"]["everydayList"]
            for data in res:
                if data["name"] == "浏览商品":
                    qd = data
                    if qd["completeStatus"] == 0:
                        shop_list = session.get(
                            "https://msec.opposhop.cn/goods/v1/SeckillRound/goods/115?pageSize=10&currentPage=1"
                        )
                        res = shop_list.json()
                        if res["meta"]["code"] == 200:
                            for skuinfo in res["detail"]:
                                skuid = skuinfo["skuid"]
                                requests.get(
                                    "https://msec.opposhop.cn/goods/v1/info/sku?skuId=" + str(skuid), headers=headers
                                )
                                time.sleep(5)
                            res2 = self.cashing_credits(
                                session=session,
                                cookie=cookie,
                                useragent=useragent,
                                info_marking=qd["marking"],
                                info_type=qd["type"],
                                info_credits=qd["credits"],
                            )
                            if res2:
                                return {"name": "浏览商品", "value": f"任务完成!积分领取+{qd['credits']}"}
                            else:
                                return {"name": "浏览商品", "value": f"领取积分奖励出错"}
                        else:
                            return {"name": "浏览商品", "value": f"错误，获取商品列表失败"}
                    elif qd["completeStatus"] == 1:
                        res2 = self.cashing_credits(
                            session=session,
                            cookie=cookie,
                            useragent=useragent,
                            info_marking=qd["marking"],
                            info_type=qd["type"],
                            info_credits=qd["credits"],
                        )
                        if res2:
                            return {"name": "浏览商品", "value": f"任务完成!积分领取+{qd['credits']}"}
                        else:
                            return {"name": "浏览商品", "value": f"领取积分奖励出错"}
                    else:
                        return {"name": "浏览商品", "value": f"任务已完成!"}
        except Exception as e:
            return {"name": "浏览商品", "value": f"错误，原因为: {e}"}

    def daily_sharegoods(self, session, cookie, useragent):
        try:
            headers = {
                "clientPackage": "com.oppo.store",
                "Host": "msec.opposhop.cn",
                "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
                "Content-Type": "application/x-www-form-urlencoded",
                "Connection": "keep-alive",
                "User-Agent": "okhttp/3.12.12.200sp1",
                "Accept-Encoding": "gzip",
                "cookie": cookie,
            }
            day_sign_list = self.task_center(session=session, cookie=cookie, useragent=useragent)
            res = day_sign_list
            res = res["data"]["everydayList"]
            for data in res:
                if data["name"] == "分享商品到微信":
                    qd = data
                    if qd["completeStatus"] == 0:
                        count = qd["readCount"]
                        endcount = qd["times"]
                        while count <= endcount:
                            session.get(
                                url="https://msec.opposhop.cn/users/vi/creditsTask/pushTask?marking=daily_sharegoods",
                                headers=headers,
                            )
                            count += 1
                        res2 = self.cashing_credits(
                            session=session,
                            cookie=cookie,
                            useragent=useragent,
                            info_marking=qd["marking"],
                            info_type=qd["type"],
                            info_credits=qd["credits"],
                        )
                        if res2:
                            return {"name": "分享商品", "value": f"任务完成!积分领取+{qd['credits']}"}
                        else:
                            return {"name": "分享商品", "value": f"领取积分奖励出错!"}
                    elif qd["completeStatus"] == 1:
                        res2 = self.cashing_credits(
                            session=session,
                            cookie=cookie,
                            useragent=useragent,
                            info_marking=qd["marking"],
                            info_type=qd["type"],
                            info_credits=qd["credits"],
                        )
                        if res2:
                            return {"name": "分享商品", "value": f"任务完成!积分领取+{qd['credits']}"}
                        else:
                            return {"name": "分享商品", "value": f"领取积分奖励出错!"}
                    else:
                        return {"name": "分享商品", "value": f"任务已完成!"}
        except Exception as e:
            return {"name": "分享商品", "value": f"错误，原因为: {e}"}

    def main(self):
        cookie = self.check_item.get("cookie")
        useragent = self.check_item.get("useragent")
        session = self.login(cookie=cookie, useragent=useragent)
        if session:
            dayily_sign_msg = self.dayily_sign(session=session, cookie=cookie, useragent=useragent)
            daily_viewgoods_msg = self.daily_viewgoods(session=session, cookie=cookie, useragent=useragent)
            daily_sharegoods_msg = self.daily_sharegoods(session=session, cookie=cookie, useragent=useragent)
            msg = [dayily_sign_msg, daily_viewgoods_msg, daily_sharegoods_msg]
        else:
            msg = [{"name": "登录信息", "value": "账号登录失败"}]
        msg = "\n".join([f"{one.get('name')}: {one.get('value')}" for one in msg])
        return msg


if __name__ == "__main__":
    with open(os.path.join(os.path.dirname(os.path.dirname(__file__)), "config.json"), "r", encoding="utf-8") as f:
        datas = json.loads(f.read())
    _check_item = datas.get("HEYTAP", [])[0]
    print(HeyTap(check_item=_check_item).main())



# -*- coding: utf-8 -*-
import json
import os

import requests

from dailycheckin import CheckIn


class EverPhoto(CheckIn):
    name = "时光相册"

    def __init__(self, check_item):
        self.check_item = check_item

    @staticmethod
    def sign(mobile, password):
        headers = {
            "content-type": "application/x-www-form-urlencoded; charset=UTF-8",
            "user-agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/93.0.4577.63 Safari/537.36 Edg/93.0.961.38",
            "accept": "*/*",
            "origin": "https://web.everphoto.cn",
            "referer": "https://web.everphoto.cn/",
            "accept-language": "zh-CN,zh;q=0.9,en;q=0.8",
        }

        data = {"mobile": mobile, "password": password}
        try:
            response = requests.post(url="https://web.everphoto.cn/api/auth", headers=headers, data=data).json()
            if response.get("code") == 0:
                data = response.get("data")
                token = data.get("token")
                mobile = data.get("user_profile", {}).get("mobile")
                return token, {"name": "账号信息", "value": mobile}
            else:
                return False, {"name": "账号信息", "value": "登录失败"}
        except Exception as e:
            return False, {"name": "账号信息", "value": "登录失败"}

    @staticmethod
    def checkin(token):
        headers = {
            "content-type": "application/x-www-form-urlencoded; charset=UTF-8",
            "user-agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/93.0.4577.63 Safari/537.36 Edg/93.0.961.38",
            "accept": "*/*",
            "origin": "https://web.everphoto.cn",
            "authorization": f"Bearer {token}",
            "referer": "https://web.everphoto.cn/",
            "accept-language": "zh-CN,zh;q=0.9,en;q=0.8",
        }
        try:
            response = requests.post(url="https://api.everphoto.cn/users/self/checkin/v2", headers=headers).json()
            if response.get("code") == 0:
                data = response.get("data")
                checkin_result = data.get("checkin_result")
                if checkin_result:
                    return {"name": "签到信息", "value": "签到成功"}
                else:
                    return {"name": "签到信息", "value": "已签到过或签到失败"}
            else:
                return {"name": "签到信息", "value": "签到失败"}
        except Exception as e:
            return {"name": "签到信息", "value": "签到失败"}

    def main(self):
        mobile = self.check_item.get("mobile")
        password = self.check_item.get("password")
        token, sign_msg = self.sign(mobile=mobile, password=password)
        msg = [sign_msg]
        if token:
            checkin_msg = self.checkin(token=token)
            msg.append(checkin_msg)
        msg = "\n".join([f"{one.get('name')}: {one.get('value')}" for one in msg])
        return msg


if __name__ == "__main__":
    with open(os.path.join(os.path.dirname(os.path.dirname(__file__)), "config.json"), "r", encoding="utf-8") as f:
        datas = json.loads(f.read())
    _check_item = datas.get("EVERPHOTO", [])[0]
    print(EverPhoto(check_item=_check_item).main())



# -*- coding: utf-8 -*-
import json
import os
import time

import requests

from dailycheckin import CheckIn


class Meizu(CheckIn):
    name = "MEIZU社区"

    def __init__(self, check_item):
        self.check_item = check_item

    @staticmethod
    def sign(cookie):
        headers = {
            "authority": "bbs-act.meizu.cn",
            "pragma": "no-cache",
            "cache-control": "no-cache",
            "accept": "application/json, text/javascript, */*; q=0.01",
            "user-agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 11_2_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/88.0.4324.182 Safari/537.36 Edg/88.0.705.74",
            "origin": "https://bbs.meizu.cn",
            "referer": "https://bbs.meizu.cn/",
            "accept-language": "zh-CN,zh;q=0.9,en;q=0.8",
            "cookie": cookie,
        }
        params = (
            ("mod", "signin"),
            ("action", "sign"),
        )
        response = requests.get(url="https://bbs-act.meizu.cn/index.php", headers=headers, params=params).json()
        msg = response.get("message")
        return msg

    @staticmethod
    def draw(cookie, count: int = 0):
        headers = {
            "authority": "bbs-act.meizu.cn",
            "accept": "application/json, text/javascript, */*; q=0.01",
            "x-requested-with": "XMLHttpRequest",
            "user-agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 11_2_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/88.0.4324.182 Safari/537.36 Edg/88.0.705.74",
            "content-type": "application/x-www-form-urlencoded",
            "origin": "https://bbs-act.meizu.cn",
            "referer": "https://bbs-act.meizu.cn/2/index.html",
            "accept-language": "zh-CN,zh;q=0.9",
            "cookie": cookie,
        }
        data = {"mod": "index", "action": "draw", "id": "2"}
        award_list = []
        success_count = 0
        error_count = 0
        if count:
            for i in range(count):
                try:
                    data = requests.post(url="https://bbs-act.meizu.cn/index.php", headers=headers, data=data).json()
                    if data["code"] == 200:
                        one_msg = data.get("data", {}).get("award_name")
                        award_list.append(one_msg)
                        success_count += 1
                    else:
                        error_count += 1
                        print(data.get("code"), data.get("message"))
                        one_msg = "抽奖失败"
                except Exception as e:
                    one_msg = f"抽奖失败: {e}"
                    error_count += 1
                print(f"第{i + 1}次抽奖结果：" + str(one_msg))
                time.sleep(5)
            msg = f"成功抽奖 {success_count} 次"
            draw_msg = [
                {"name": "抽奖信息", "value": str(msg)},
                {"name": "抽奖结果", "value": ";".join(award_list)},
            ]
        else:
            draw_msg = [
                {"name": "抽奖信息", "value": "未开启抽奖"},
            ]
        data = {"mod": "index", "action": "get_user_count", "id": "2"}
        user_info = requests.post("https://bbs-act.meizu.cn/index.php", headers=headers, data=data).json()
        uid = user_info.get("data", {}).get("uid")
        return draw_msg, uid

    def main(self):
        meizu_cookie = self.check_item.get("cookie")
        try:
            draw_count = int(self.check_item.get("draw_count", 0))
        except Exception as e:
            print("初始化抽奖次数失败: 重置为 0 ", str(e))
            draw_count = 0
        sign_msg = self.sign(cookie=meizu_cookie)
        draw_msg, uid = self.draw(cookie=meizu_cookie, count=draw_count)
        msg = [
                  {"name": "帐号信息", "value": uid},
                  {"name": "签到信息", "value": sign_msg},
              ] + draw_msg
        msg = "\n".join([f"{one.get('name')}: {one.get('value')}" for one in msg])
        return msg


if __name__ == "__main__":
    with open(os.path.join(os.path.dirname(os.path.dirname(__file__)), "config.json"), "r", encoding="utf-8") as f:
        datas = json.loads(f.read())
    _check_item = datas.get("MEIZU", [])[0]
    print(Meizu(check_item=_check_item).main())



# -*- coding: utf-8 -*-
import base64
import hashlib
import hmac
import json
import time
import urllib.parse

import requests


def message2server(sckey, content):
    print("server 酱推送开始")
    data = {"text": "每日签到", "desp": content.replace("\n", "\n\n")}
    requests.post(url=f"https://sc.ftqq.com/{sckey}.send", data=data)
    return


def message2server_turbo(sendkey, content):
    print("server 酱 Turbo 推送开始")
    data = {"text": "每日签到", "desp": content.replace("\n", "\n\n")}
    requests.post(url=f"https://sctapi.ftqq.com/{sendkey}.send", data=data)
    return


def message2coolpush(
    coolpushskey, content, coolpushqq: bool = True, coolpushwx: bool = False, coolpushemail: bool = False
):
    print("Cool Push 推送开始")
    params = {"c": content, "t": "每日签到"}
    if coolpushqq:
        requests.post(url=f"https://push.xuthus.cc/send/{coolpushskey}", params=params)
    if coolpushwx:
        requests.post(url=f"https://push.xuthus.cc/wx/{coolpushskey}", params=params)
    if coolpushemail:
        requests.post(url=f"https://push.xuthus.cc/email/{coolpushskey}", params=params)
    return


def message2qmsg(qmsg_key, qmsg_type, content):
    print("qmsg 酱推送开始")
    params = {"msg": content}
    if qmsg_type == "group":
        requests.get(url=f"https://qmsg.zendee.cn/group/{qmsg_key}", params=params)
    else:
        requests.get(url=f"https://qmsg.zendee.cn/send/{qmsg_key}", params=params)
    return


def message2telegram(tg_api_host, tg_proxy, tg_bot_token, tg_user_id, content):
    print("Telegram 推送开始")
    send_data = {"chat_id": tg_user_id, "text": content, "disable_web_page_preview": "true"}
    if tg_api_host:
        url = f"https://{tg_api_host}/bot{tg_bot_token}/sendMessage"
    else:
        url = f"https://api.telegram.org/bot{tg_bot_token}/sendMessage"
    if tg_proxy:
        proxies = {
            "http": tg_proxy,
            "https": tg_proxy,
        }
    else:
        proxies = None
    requests.post(url=url, data=send_data, proxies=proxies)
    return


def message2feishu(fskey, content):
    print("飞书 推送开始")
    data = {"msg_type": "text", "content": {"text": content}}
    requests.post(url=f"https://open.feishu.cn/open-apis/bot/v2/hook/{fskey}", json=data)
    return


def message2dingtalk(dingtalk_secret, dingtalk_access_token, content):
    print("Dingtalk 推送开始")
    timestamp = str(round(time.time() * 1000))
    secret_enc = dingtalk_secret.encode("utf-8")
    string_to_sign = "{}\n{}".format(timestamp, dingtalk_secret)
    string_to_sign_enc = string_to_sign.encode("utf-8")
    hmac_code = hmac.new(secret_enc, string_to_sign_enc, digestmod=hashlib.sha256).digest()
    sign = urllib.parse.quote_plus(base64.b64encode(hmac_code))
    send_data = {"msgtype": "text", "text": {"content": content}}
    requests.post(
        url="https://oapi.dingtalk.com/robot/send?access_token={0}&timestamp={1}&sign={2}".format(
            dingtalk_access_token, timestamp, sign
        ),
        headers={"Content-Type": "application/json", "Charset": "UTF-8"},
        data=json.dumps(send_data),
    )
    return


def message2bark(bark_url: str, content):
    print("Bark 推送开始")
    if not bark_url.endswith("/"):
        bark_url += "/"
    url = f"{bark_url}{content}"
    headers = {"Content-type": "application/x-www-form-urlencoded"}
    requests.get(url=url, headers=headers)
    return


def message2qywxrobot(qywx_key, content):
    print("企业微信群机器人推送开始")
    requests.post(
        url=f"https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key={qywx_key}",
        data=json.dumps({"msgtype": "text", "text": {"content": content}}),
    )
    return


def message2qywxapp(qywx_corpid, qywx_agentid, qywx_corpsecret, qywx_touser, qywx_media_id, content):
    print("企业微信应用消息推送开始")
    res = requests.get(
        f"https://qyapi.weixin.qq.com/cgi-bin/gettoken?corpid={qywx_corpid}&corpsecret={qywx_corpsecret}"
    )
    token = res.json().get("access_token", False)
    if qywx_media_id:
        data = {
            "touser": qywx_touser,
            "msgtype": "mpnews",
            "agentid": int(qywx_agentid),
            "mpnews": {
                "articles": [
                    {
                        "title": "Dailycheckin 签到通知",
                        "thumb_media_id": qywx_media_id,
                        "author": "Sitoi",
                        "content_source_url": "https://github.com/Sitoi/dailycheckin",
                        "content": content.replace("\n", "<br>"),
                        "digest": content,
                    }
                ]
            },
        }
    else:
        data = {
            "touser": qywx_touser,
            "agentid": int(qywx_agentid),
            "msgtype": "textcard",
            "textcard": {
                "title": "Dailycheckin 签到通知",
                "description": content,
                "url": "https://github.com/Sitoi/dailycheckin",
                "btntxt": "开源项目",
            },
        }
    requests.post(url=f"https://qyapi.weixin.qq.com/cgi-bin/message/send?access_token={token}", data=json.dumps(data))
    return


def message2pushplus(pushplus_token, content, pushplus_topic=None):
    print("Pushplus 推送开始")
    data = {"token": pushplus_token, "title": "签到通知", "content": content.replace("\n", "<br>"), "template": "json"}
    if pushplus_topic:
        data["topic"] = pushplus_topic
    requests.post(url=f"http://www.pushplus.plus/send", data=json.dumps(data))
    return


def important_notice():
    datas = requests.get(url="https://api.github.com/repos/Sitoi/dailycheckin/issues?state=open&labels=通知").json()
    if datas:
        data = datas[0]
        title = data.get("title")
        body = data.get("body")
        url = data.get("html_url")
        notice = f"{title}\n{body}\n详细地址: {url}"
    else:
        notice = None
    return notice


def push_message(content_list: list, notice_info: dict):
    dingtalk_secret = notice_info.get("dingtalk_secret")
    dingtalk_access_token = notice_info.get("dingtalk_access_token")
    fskey = notice_info.get("fskey")
    bark_url = notice_info.get("bark_url")
    sckey = notice_info.get("sckey")
    sendkey = notice_info.get("sendkey")
    qmsg_key = notice_info.get("qmsg_key")
    qmsg_type = notice_info.get("qmsg_type")
    tg_bot_token = notice_info.get("tg_bot_token")
    tg_user_id = notice_info.get("tg_user_id")
    tg_api_host = notice_info.get("tg_api_host")
    tg_proxy = notice_info.get("tg_proxy")
    coolpushskey = notice_info.get("coolpushskey")
    coolpushqq = notice_info.get("coolpushqq")
    coolpushwx = notice_info.get("coolpushwx")
    coolpushemail = notice_info.get("coolpushemail")
    qywx_key = notice_info.get("qywx_key")
    qywx_corpid = notice_info.get("qywx_corpid")
    qywx_agentid = notice_info.get("qywx_agentid")
    qywx_corpsecret = notice_info.get("qywx_corpsecret")
    qywx_touser = notice_info.get("qywx_touser")
    qywx_media_id = notice_info.get("qywx_media_id")
    pushplus_token = notice_info.get("pushplus_token")
    pushplus_topic = notice_info.get("pushplus_topic")
    merge_push = notice_info.get("merge_push")
    content_str = "\n————————————\n\n".join(content_list)
    message_list = [content_str]
    try:
        notice = important_notice()
        if notice:
            message_list.append(notice)
            content_list.append(notice)
    except Exception as e:
        print("获取重要通知失败:", e)
    if merge_push is None:
        if qmsg_key or coolpushskey or qywx_touser or qywx_corpsecret or qywx_agentid or bark_url:
            merge_push = False
        else:
            merge_push = True
    if not merge_push:
        message_list = content_list
    for message in message_list:
        if qmsg_key:
            try:
                message2qmsg(qmsg_key=qmsg_key, qmsg_type=qmsg_type, content=message)
            except Exception as e:
                print("qmsg 推送失败", e)
        if coolpushskey:
            try:
                message2coolpush(
                    coolpushskey=coolpushskey,
                    coolpushqq=coolpushqq,
                    coolpushwx=coolpushwx,
                    coolpushemail=coolpushemail,
                    content=message,
                )
            except Exception as e:
                print("coolpush 推送失败", e)
        if qywx_touser and qywx_corpid and qywx_corpsecret and qywx_agentid:
            try:
                message2qywxapp(
                    qywx_corpid=qywx_corpid,
                    qywx_agentid=qywx_agentid,
                    qywx_corpsecret=qywx_corpsecret,
                    qywx_touser=qywx_touser,
                    qywx_media_id=qywx_media_id,
                    content=message,
                )
            except Exception as e:
                print("企业微信应用消息推送失败", e)
        if bark_url:
            try:
                message2bark(bark_url=bark_url, content=message)
            except Exception as e:
                print("Bark 推送失败", e)
        if dingtalk_access_token and dingtalk_secret:
            try:
                message2dingtalk(
                    dingtalk_secret=dingtalk_secret, dingtalk_access_token=dingtalk_access_token, content=message
                )
            except Exception as e:
                print("钉钉推送失败", e)
        if fskey:
            try:
                message2feishu(fskey=fskey, content=message)
            except Exception as e:
                print("飞书推送失败", e)
        if sckey:
            try:
                message2server(sckey=sckey, content=message)
            except Exception as e:
                print("Server 推送失败", e)
        if sendkey:
            try:
                message2server_turbo(sendkey=sendkey, content=message)
            except Exception as e:
                print("Server Turbo 推送失败", e)
        if qywx_key:
            try:
                message2qywxrobot(qywx_key=qywx_key, content=message)
            except Exception as e:
                print("企业微信群机器人推送失败", e)
        if pushplus_token:
            try:
                message2pushplus(pushplus_token=pushplus_token, content=message, pushplus_topic=pushplus_topic)
            except Exception as e:
                print("Pushplus 推送失败", e)
        if tg_user_id and tg_bot_token:
            try:
                message2telegram(
                    tg_api_host=tg_api_host,
                    tg_proxy=tg_proxy,
                    tg_user_id=tg_user_id,
                    tg_bot_token=tg_bot_token,
                    content=message,
                )
            except Exception as e:
                print("Telegram 推送失败", e)


if __name__ == "__main__":
    print(important_notice())



# -*- coding: utf-8 -*-
import hashlib
import json
import os
import re

import requests
from requests import utils

from dailycheckin import CheckIn


class Tieba(CheckIn):
    name = "百度贴吧"

    def __init__(self, check_item):
        self.check_item = check_item

    @staticmethod
    def login_info(session):
        return session.get(url="https://zhidao.baidu.com/api/loginInfo").json()

    def valid(self, session):
        try:
            content = session.get(url="http://tieba.baidu.com/dc/common/tbs")
        except Exception as e:
            return False, f"登录验证异常,错误信息: {e}"
        data = json.loads(content.text)
        if data["is_login"] == 0:
            return False, "登录失败,cookie 异常"
        tbs = data["tbs"]
        user_name = self.login_info(session=session)["userName"]
        return tbs, user_name

    @staticmethod
    def tieba_list_more(session):
        content = session.get(url="http://tieba.baidu.com/f/like/mylike?&pn=1", timeout=(5, 20), allow_redirects=False)
        try:
            pn = int(re.match(r".*/f/like/mylike\?&pn=(.*?)\">尾页.*", content.text, re.S | re.I).group(1))
        except Exception as e:
            pn = 1
        next_page = 1
        pattern = re.compile(r".*?<a href=\"/f\?kw=.*?title=\"(.*?)\">")
        while next_page <= pn:
            tbname = pattern.findall(content.text)
            for x in tbname:
                yield x
            next_page += 1
            content = session.get(
                url=f"http://tieba.baidu.com/f/like/mylike?&pn={next_page}", timeout=(5, 20), allow_redirects=False
            )

    def get_tieba_list(self, session):
        tieba_list = list(self.tieba_list_more(session=session))
        return tieba_list

    @staticmethod
    def sign(session, tb_name_list, tbs):
        success_count, error_count, exist_count, shield_count = 0, 0, 0, 0
        for tb_name in tb_name_list:
            md5 = hashlib.md5(f"kw={tb_name}tbs={tbs}tiebaclient!!!".encode("utf-8")).hexdigest()
            data = {"kw": tb_name, "tbs": tbs, "sign": md5}
            try:
                response = session.post(url="http://c.tieba.baidu.com/c/c/forum/sign", data=data).json()
                if response["error_code"] == "0":
                    success_count += 1
                elif response["error_code"] == "160002":
                    exist_count += 1
                elif response["error_code"] == "340006":
                    shield_count += 1
                else:
                    error_count += 1
            except Exception as e:
                print(f"贴吧 {tb_name} 签到异常,原因{str(e)}")
        msg = [
            {"name": "贴吧总数", "value": len(tb_name_list)},
            {"name": "签到成功", "value": success_count},
            {"name": "已经签到", "value": exist_count},
            {"name": "被屏蔽的", "value": shield_count},
            {"name": "签到失败", "value": error_count},
        ]
        return msg

    def main(self):
        tieba_cookie = {item.split("=")[0]: item.split("=")[1] for item in self.check_item.get("cookie").split("; ")}
        session = requests.session()
        requests.utils.add_dict_to_cookiejar(session.cookies, tieba_cookie)
        session.headers.update({"Referer": "https://www.baidu.com/"})
        tbs, user_name = self.valid(session=session)
        if tbs:
            tb_name_list = self.get_tieba_list(session=session)
            msg = self.sign(session=session, tb_name_list=tb_name_list, tbs=tbs)
            msg = [{"name": "帐号信息", "value": user_name}] + msg
        else:
            msg = [
                {"name": "帐号信息", "value": user_name},
                {"name": "签到信息", "value": "Cookie 可能过期"},
            ]
        msg = "\n".join([f"{one.get('name')}: {one.get('value')}" for one in msg])
        return msg


if __name__ == "__main__":
    with open(os.path.join(os.path.dirname(os.path.dirname(__file__)), "config.json"), "r", encoding="utf-8") as f:
        datas = json.loads(f.read())
    _check_item = datas.get("TIEBA", [])[0]
    print(Tieba(check_item=_check_item).main())



# -*- coding: utf-8 -*-
import json
import os
import re

import requests
import urllib3
from requests import utils

from dailycheckin import CheckIn

urllib3.disable_warnings()


class WWW2NZZ(CheckIn):
    name = "咔叽网单"

    def __init__(self, check_item):
        self.check_item = check_item

    @staticmethod
    def sign(session):
        response = session.get(url="http://www.2nzz.com/index.php", verify=False)
        formhash = re.findall(r'<input type="hidden" name="formhash" value="(.*?)"', response.text)[0]
        params = (
            ("id", "dsu_paulsign:sign"),
            ("operation", "qiandao"),
            ("infloat", "1"),
            ("sign_as", "1"),
            ("inajax", "1"),
        )
        data = {"formhash": formhash, "qdxq": "kx", "qdmode": "2", "todaysay": "", "fastreply": "0"}
        response = session.post(url="http://www.2nzz.com/plugin.php", params=params, data=data, verify=False)
        user_rep = session.get(url="http://www.2nzz.com/home.php")
        uid = re.findall(r"uid=(\d+)\"", user_rep.text)
        uid = uid[0] if uid else "未获取到 UID"
        if "您今天已经签到过了或者签到时间还未开始" in response.text:
            msg = [
                {"name": "账号信息", "value": uid},
                {"name": "签到信息", "value": "您今天已经签到过了或者签到时间还未开始"},
            ]
        else:
            check_msg = re.findall(r"<div class=\"c\">(.*?)</div>", response.text, re.S)
            check_msg = check_msg[0].strip() if check_msg else "签到失败"
            msg = [
                {"name": "账号信息", "value": uid},
                {"name": "签到信息", "value": check_msg},
            ]
        return msg

    def main(self):
        cookie = {item.split("=")[0]: item.split("=")[1] for item in self.check_item.get("cookie").split("; ")}
        session = requests.session()
        requests.utils.add_dict_to_cookiejar(session.cookies, cookie)
        session.headers.update(
            {
                "Origin": "http://www.2nzz.com",
                "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/88.0.4324.182 Safari/537.36 Edg/88.0.705.74",
                "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
                "Referer": "http://www.2nzz.com/index.php",
                "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
            }
        )
        msg = self.sign(session=session)
        msg = "\n".join([f"{one.get('name')}: {one.get('value')}" for one in msg])
        return msg


if __name__ == "__main__":
    with open(os.path.join(os.path.dirname(os.path.dirname(__file__)), "config.json"), "r", encoding="utf-8") as f:
        datas = json.loads(f.read())
    _check_item = datas.get("WWW2NZZ", [])[0]
    print(WWW2NZZ(check_item=_check_item).main())



# -*- coding: utf-8 -*-
import base64
import json
import os
import random
import re
import time

import requests
import rsa

from dailycheckin import CheckIn


class UniCom(CheckIn):
    name = "联通营业厅"

    def __init__(self, check_item):
        self.check_item = check_item

    @staticmethod
    def str2key(s):
        b_str = base64.b64decode(s)
        if len(b_str) < 162:
            return False
        hex_str = ""
        for x in b_str:
            h = hex(x)[2:]
            h = h.rjust(2, "0")
            hex_str += h
        m_start = 29 * 2
        e_start = 159 * 2
        m_len = 128 * 2
        e_len = 3 * 2
        modulus = hex_str[m_start: m_start + m_len]
        exponent = hex_str[e_start: e_start + e_len]
        return modulus, exponent

    @staticmethod
    def encryption(message, key):
        modulus = int(key[0], 16)
        exponent = int(key[1], 16)
        rsa_pubkey = rsa.PublicKey(modulus, exponent)
        crypto = rsa.encrypt(message, rsa_pubkey)
        b64str = base64.b64encode(crypto)
        return b64str

    def login(self, mobile, password, app_id):
        session = requests.Session()
        pubkey = "MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQDc+CZK9bBA9IU+gZUOc6FUGu7yO9WpTNB0PzmgFBh96Mg1WrovD1oqZ+eIF4LjvxKXGOdI79JRdve9NPhQo07+uqGQgE4imwNnRx7PFtCRryiIEcUoavuNtuRVoBAm6qdB0SrctgaqGfLgKvZHOnwTjyNqjBUxzMeQlEC2czEMSwIDAQAB"
        key = self.str2key(pubkey)
        mobile = self.encryption(str.encode(mobile), key)
        password = self.encryption(str.encode(password), key)
        flag = False
        cookies = {
            "c_sfbm": "234g_00",
            "logHostIP": "null",
            "route": "cc3839c658dd60cb7c25f6c2fe6eb964",
            "channel": "GGPD",
            "city": "076|776",
            "devicedId": "B97CDE2A-D435-437D-9FEC-5D821A012972",
            "mobileService1": "ProEsSI6SM4DbWhaeVsPtve9pu7VWz0m94giTHkPBl40Gx8nebgV!-1027473388",
            "mobileServiceAll": "a92d76b26705a45a087027f893c70618",
        }

        headers = {
            "Host": "m.client.10010.com",
            "Accept": "/",
            "Content-Type": "application/x-www-form-urlencoded",
            "Connection": "keep-alive",
            "User-Agent": "ChinaUnicom4.x/3.0 CFNetwork/1197 Darwin/20.0.0",
            "Accept-Language": "zh-cn",
            "Accept-Encoding": "deflate, br",
            "Content-Length": "891",
        }

        data = {
            "reqtime": round(time.time() * 1000),
            "simCount": "1",
            "version": "iphone_c@8.0004",
            "mobile": mobile,
            "netWay": "wifi",
            "isRemberPwd": "false",
            "appId": app_id,
            "deviceId": "b61f7efcba733583170df52d8f2f9f87521b3844d01ccbc774bbfa379eaeb3fa",
            "pip": "192.168.1.4",
            "password": password,
            "deviceOS": "14.0.1",
            "deviceBrand": "iphone",
            "deviceModel": "iPad",
            "remark4": "",
            "keyVersion": "",
            "deviceCode": "B97CDE2A-D435-437D-9FEC-5D821A012972",
        }

        response = session.post(
            url="https://m.client.10010.com/mobileService/login.htm", headers=headers, cookies=cookies, data=data
        )
        response.encoding = "utf-8"
        try:
            result = response.json()
            if result["code"] == "0":
                login_msg = {"name": "账号信息", "value": result["default"][:4] + "xxxx" + result["default"][-4:]}
                session.headers.update(
                    {
                        "User-Agent": "Mozilla/5.0 (Linux; Android 10; RMX1901 Build/QKQ1.190918.001; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/74.0.3729.186 Mobile Safari/537.36; unicom{version:android@8.0100,desmobile:"
                                      + str(mobile)
                                      + "};devicetype{deviceBrand:Realme,deviceModel:RMX1901};{yw_code:}"
                    }
                )
                flag = True
            else:
                login_msg = {"name": "账号信息", "value": result["dsc"]}
        except Exception as e:
            login_msg = {"name": "账号信息", "value": str(e)}
        if flag:
            return session, login_msg
        else:
            return False, login_msg

    @staticmethod
    def get_encryptmobile(session):
        page = session.post(url="https://m.client.10010.com/dailylottery/static/textdl/userLogin")
        page.encoding = "utf-8"
        match = re.search(r"encryptmobile=\w+", page.text, flags=0)
        user_number = match.group(0)[14:]
        return user_number

    # 每日签到
    @staticmethod
    def daily_daysign(session, mobile):
        try:
            session.headers.update({"referer": "https://img.client.10010.com/activitys/member/index.html"})
            param = f"yw_code=&desmobile={mobile}&version=android@$8.0100"
            session.get(url="https://act.10010.com/SigninApp/signin/querySigninActivity.htm?" + param)
            session.headers.update(
                {"referer": "https://act.10010.com/SigninApp/signin/querySigninActivity.htm?" + param}
            )
            day_sign = session.post(url="https://act.10010.com/SigninApp/signin/daySign")
            day_sign.encoding = "utf-8"
            session.post(url="https://act.10010.com/SigninApp/signin/todaySign")
            session.post(url="https://act.10010.com/SigninApp/signin/addIntegralDA")
            session.post(url="https://act.10010.com/SigninApp/signin/getContinuous")
            session.post(url="https://act.10010.com/SigninApp/signin/getIntegral")
            session.post(url="https://act.10010.com/SigninApp/signin/getGoldTotal")
            session.headers.pop("referer")
            res = day_sign.json()
            if res["status"] == "0000":
                return {"name": "每日签到", "value": f"打卡成功!"}
            elif res["status"] == "0002":
                return {"name": "每日签到", "value": res["msg"]}
        except Exception as e:
            return {"name": "每日签到", "value": f"错误，原因为: {e}"}

    def daily_lottery(self, session):
        daily_lottery_msg = []
        try:
            numjsp = self.get_encryptmobile(session=session)
            session.post(url="https://m.client.10010.com/mobileservicequery/customerService/share/defaultShare.htm")
            session.get(
                url="https://m.client.10010.com/dailylottery/static/doubleball/firstpage?encryptmobile=" + numjsp
            )
            session.get(
                url="https://m.client.10010.com/dailylottery/static/outdailylottery/getRandomGoodsAndInfo?areaCode=076"
            )
            session.get(
                url="https://m.client.10010.com/dailylottery/static/active/findActivityInfo?areaCode=076&groupByType=&mobile="
                    + numjsp
            )
            for i in range(3):
                luck = session.post(
                    url="https://m.client.10010.com/dailylottery/static/doubleball/choujiang?usernumberofjsp=" + numjsp
                )
                luck.encoding = "utf-8"
                res = luck.json()
                daily_lottery_msg.append(res["RspMsg"])
        except Exception as e:
            daily_lottery_msg.append(str(e))
        return {"name": "天天抽奖", "value": ";".join(daily_lottery_msg)}

    def points_lottery(self, session):
        try:
            numjsp = self.get_encryptmobile(session=session)
            one_free = session.post(
                url="https://m.client.10010.com/dailylottery/static/integral/choujiang?usernumberofjsp=" + numjsp
            )
            one_free.encoding = "utf-8"
            res = one_free.json()
            jifeng_msg = res["RspMsg"]
        except Exception as e:
            jifeng_msg = str(e)
        return {"name": "积分抽奖", "value": jifeng_msg}

    @staticmethod
    def game_signin(session, mobile):
        data = {"methodType": "iOSIntegralGet", "gameLevel": "1", "deviceType": "iOS"}
        try:
            session.get(
                url=f"https://img.client.10010.com/gametask/index.html?yw_code=&desmobile={mobile}&version=android@8.0100"
            )
            time.sleep(2)
            headers = {
                "origin": "https://img.client.10010.com",
                "referer": f"https://img.client.10010.com/gametask/index.html?yw_code=&desmobile={mobile}&version=android@8.0100",
            }
            session.headers.update(headers)
            game_center_exp = session.post(url="https://m.client.10010.com/producGameApp", data=data)
            game_center_exp.encoding = "utf-8"
            res = game_center_exp.json()
            session.headers.pop("referer")
            session.headers.pop("origin")
            time.sleep(1)
            if res["code"] == "0000":
                return {"name": "游戏频道打卡", "value": f"获得{res['integralNum']}积分"}
            else:
                return {"name": "游戏频道打卡", "value": res["msg"]}
        except Exception as e:
            return {"name": "游戏频道打卡", "value": f"错误，原因为: {e}"}

    @staticmethod
    def daily_integral_100(session):
        data = {"from": random.choice("123456789") + "".join(random.choice("0123456789") for i in range(10))}
        try:
            integral = session.post(
                url="https://m.client.10010.com/welfare-mall-front/mobile/integral/gettheintegral/v1", data=data
            )
            integral.encoding = "utf-8"
            res = integral.json()
            return {"name": "100定向积分", "value": res["msg"]}
        except Exception as e:
            return {"name": "100定向积分", "value": str(e)}

    @staticmethod
    def game_dongao(session):
        data = {"from": random.choice("123456789") + "".join(random.choice("0123456789") for i in range(10))}
        trance = [600, 300, 300, 300, 300, 300, 300]
        try:
            dongao_point = session.post(
                url="https://m.client.10010.com/welfare-mall-front/mobile/winterTwo/getIntegral/v1", data=data
            )
            dongao_point.encoding = "utf-8"
            res1 = dongao_point.json()
            dongao_num = session.post(
                url="https://m.client.10010.com/welfare-mall-front/mobile/winterTwo/winterTwoShop/v1", data=data
            )
            dongao_num.encoding = "utf-8"
            res2 = dongao_num.json()
            if res1["resdata"]["code"] == "0000":
                return {
                    "name": "冬奥积分活动",
                    "value": res1["resdata"]["desc"] + "，" + str(trance[int(res2["resdata"]["signDays"])]) + "积分",
                }

            else:
                return {"name": "冬奥积分活动", "value": res1["resdata"]["desc"] + "，" + res2["resdata"]["desc"]}
        except Exception as e:
            return {"name": "冬奥积分活动", "value": str(e)}

    @staticmethod
    def get_wotree_glowlist(session):
        response = session.post(url="https://m.client.10010.com/mactivity/arbordayJson/index.htm")
        res = response.json()
        return res["data"]["flowChangeList"]

    def wo_tree(self, session):
        try:
            flow_list = self.get_wotree_glowlist(session)
            num = 1
            for flow in flow_list:
                # 这里会请求很长时间，发送即请求成功
                flag = False
                try:
                    take_flow = session.get(
                        url="https://m.client.10010.com/mactivity/flowData/takeFlow.htm?flowId=" + flow["id"], timeout=1
                    )
                    take_flow.encoding = "utf-8"
                except Exception as e:
                    flag = True
                    print("【沃之树-领流量】: 4M流量 x" + str(num))
                time.sleep(1)
                num = num + 1
                if flag:
                    continue
                res1 = take_flow.json()
                if res1["code"] == "0000":
                    print("【沃之树-领流量】: 4M流量 x" + str(num))
                else:
                    print("【沃之树-领流量】: 已领取过 x" + str(num))
                time.sleep(1)
                num = num + 1
            session.post(url="https://m.client.10010.com/mactivity/arbordayJson/getChanceByIndex.htm?index=0")
            grow = session.post(url="https://m.client.10010.com/mactivity/arbordayJson/arbor/3/0/3/grow.htm")
            grow.encoding = "utf-8"
            res2 = grow.json()
            time.sleep(1)
            return {"name": "沃之树-浇水", "value": str(res2["data"]["addedValue"]) + "培养值"}
        except Exception as e:
            return {"name": "沃之树-浇水", "value": str(e)}

    @staticmethod
    def user_info(session):
        resp = session.get(url="https://m.client.10010.com/mobileService/home/queryUserInfoSeven.htm?showType=3")
        user_info_msg = []
        try:
            for one in resp.json().get("data", {}).get("dataList", []):
                user_info_msg.append({"name": one.get("remainTitle"), "value": one.get("number") + one.get("unit")})
        except Exception as e:
            print(e)
        return user_info_msg

    def main(self):
        mobile = self.check_item.get("mobile")
        password = self.check_item.get("password")
        app_id = self.check_item.get("app_id")
        session, login_msg = self.login(mobile=mobile, password=password, app_id=app_id)
        if session:
            daily_daysign_msg = self.daily_daysign(session=session, mobile=mobile)
            daily_integral_100_msg = self.daily_integral_100(session=session)
            daily_lottery_msg = self.daily_lottery(session=session)
            game_dongao_msg = self.game_dongao(session=session)
            game_signin_msg = self.game_signin(session=session, mobile=mobile)
            points_lottery_msg = self.points_lottery(session=session)
            wo_tree_msg = self.wo_tree(session=session)
            user_info_msg = self.user_info(session=session)
            msg = [
                      login_msg,
                      daily_daysign_msg,
                      daily_integral_100_msg,
                      daily_lottery_msg,
                      game_dongao_msg,
                      game_signin_msg,
                      points_lottery_msg,
                      wo_tree_msg,
                  ] + user_info_msg
        else:
            msg = [login_msg]
        msg = "\n".join([f"{one.get('name')}: {one.get('value')}" for one in msg])
        return msg


if __name__ == "__main__":
    with open(os.path.join(os.path.dirname(os.path.dirname(__file__)), "config.json"), "r", encoding="utf-8") as f:
        datas = json.loads(f.read())
    _check_item = datas.get("UNICOM", [])[0]
    print(UniCom(check_item=_check_item).main())



# -*- coding: utf-8 -*-
import json
import os
from urllib import parse

import requests

from dailycheckin import CheckIn


class Baidu(CheckIn):
    name = "百度站点提交"

    def __init__(self, check_item: dict):
        self.check_item = check_item

    @staticmethod
    def url_submit(data_url: str, submit_url: str, times: int = 100) -> str:
        site = parse.parse_qs(parse.urlsplit(submit_url).query).get("site")[0]
        urls_data = requests.get(url=data_url)
        remian = 100000
        success_count = 0
        error_count = 0
        for one in range(times):
            try:
                response = requests.post(url=submit_url, data=urls_data)
                if response.json().get("success"):
                    remian = response.json().get("remain")
                    success_count += response.json().get("success")
                else:
                    error_count += 1
            except Exception as e:
                print(e)
                error_count += 1
        msg = [
            {"name": "站点地址", "value": site},
            {"name": "剩余条数", "value": remian},
            {"name": "成功条数", "value": success_count},
            {"name": "成功次数", "value": times - error_count},
            {"name": "失败次数", "value": error_count},
        ]
        return msg

    def main(self):
        data_url = self.check_item.get("data_url")
        submit_url = self.check_item.get("submit_url")
        times = int(self.check_item.get("times", 100))
        if data_url and submit_url:
            msg = self.url_submit(data_url=data_url, submit_url=submit_url, times=times)
        else:
            msg = {"name": "站点配置", "value": "配置错误"}
        msg = "\n".join([f"{one.get('name')}: {one.get('value')}" for one in msg])
        return msg


if __name__ == "__main__":
    with open(os.path.join(os.path.dirname(os.path.dirname(__file__)), "config.json"), "r", encoding="utf-8") as f:
        datas = json.loads(f.read())
    _check_item = datas.get("BAIDU", [])[0]
    print(Baidu(check_item=_check_item).main())



# -*- coding: utf-8 -*-
import json
import os
import re
import time

import requests

from dailycheckin import CheckIn


class WoMail(CheckIn):
    name = "沃邮箱"

    def __init__(self, check_item):
        self.check_item = check_item

    @staticmethod
    def login(womail_url):
        try:
            url = womail_url
            headers = {
                "User-Agent": "User-Agent: Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.25 Safari/537.36 Core/1.70.3868.400 QQBrowser/10.8.4394.400"
            }
            res = requests.get(url=url, headers=headers, allow_redirects=False)
            set_cookie = res.headers["Set-Cookie"]
            cookies = re.findall("YZKF_SESSION.*?;", set_cookie)[0]
            if "YZKF_SESSION" in cookies:
                return cookies
            else:
                print("沃邮箱获取 cookies 失败")
                return None
        except Exception as e:
            print("沃邮箱错误:", e)
            return None

    @staticmethod
    def dotask(cookies):
        msg = []
        headers = {
            "User-Agent": "User-Agent: Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.25 Safari/537.36 Core/1.70.3868.400 QQBrowser/10.8.4394.400",
            "Cookie": cookies,
        }
        try:
            url = "https://nyan.mail.wo.cn/cn/sign/index/userinfo.do?rand=0.8897817905278955"
            res = requests.post(url=url, headers=headers)
            result = res.json()
            wxname = result.get("result").get("wxName")
            usermobile = result.get("result").get("userMobile")
            keep_sign = result["result"]["keepSign"]
            msg.append({"name": "帐号信息", "value": f"{wxname} - {usermobile[:3]}****{usermobile[-4:]}"})
        except Exception as e:
            keep_sign = 0
            msg.append({"name": "帐号信息", "value": str(e)})
        try:
            if keep_sign >= 21:
                msg.append({"name": "每日签到", "value": f"昨日为打卡{keep_sign}天，今日暂停打卡"})
            else:
                url = "https://nyan.mail.wo.cn/cn/sign/user/checkin.do?rand=0.913524814493383"
                res = requests.post(url=url, headers=headers).json()
                result = res.get("result")
                if result == -2:
                    msg.append({"name": "每日签到", "value": f"已签到 {keep_sign} 天"})
                elif result is None:
                    msg.append({"name": "每日签到", "value": f"签到失败"})
                else:
                    msg.append({"name": "每日签到", "value": f"签到成功~已签到{result}天！"})
        except Exception as e:
            msg.append({"name": "每日签到", "value": str(e)})
        try:
            url = "https://nyan.mail.wo.cn/cn/sign/user/doTask.do?rand=0.8776674762904109"
            data_params = {
                "每日首次登录手机邮箱": {"taskName": "loginmail"},
                "去用户俱乐部逛一逛": {"taskName": "club"},
                "小积分抽大奖": {"taskName": "clubactivity"},
                "每日答题赢奖": {"taskName": "answer"},
                "下载沃邮箱": {"taskName": "download"},
            }
            for key, data in data_params.items():
                try:
                    res = requests.post(url=url, data=data, headers=headers).json()
                    result = res.get("result")
                    if result == 1:
                        msg.append({"name": key, "value": "做任务成功"})
                    elif result == -1:
                        msg.append({"name": key, "value": "任务已做过"})
                    elif result == -2:
                        msg.append({"name": key, "value": "请检查登录状态"})
                    else:
                        msg.append({"name": key, "value": "未知错误"})
                except Exception as e:
                    msg.append({"name": key, "value": str(e)})
        except Exception as e:
            msg.append({"name": "执行任务错误", "value": str(e)})
        return msg

    @staticmethod
    def dotask2(womail_url):
        msg = []
        userdata = re.findall("mobile.*", womail_url)[0]
        url = "https://club.mail.wo.cn/clubwebservice/?" + userdata
        headers = {
            "User-Agent": "User-Agent: Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.25 Safari/537.36 Core/1.70.3868.400 QQBrowser/10.8.4394.400"
        }
        try:
            res = requests.get(url=url, headers=headers, allow_redirects=False)
            set_cookie = res.headers["Set-Cookie"]
            cookies = re.findall("SESSION.*?;", set_cookie)[0]
            if "SESSION" in cookies:
                headers = {
                    "User-Agent": "User-Agent: Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.25 Safari/537.36 Core/1.70.3868.400 QQBrowser/10.8.4394.400",
                    "Cookie": cookies,
                    "Referer": "https://club.mail.wo.cn/clubwebservice/club-user/user-info/mine-task",
                }
                # 获取账号信息
                try:
                    url = "https://club.mail.wo.cn/clubwebservice/club-user/user-info/get-user-score-info/"
                    res = requests.get(url=url, headers=headers)
                    result = res.json()
                    integraltotal = result.get("integralTotal")
                    usermobile = result.get("userPhoneNum")
                    msg.append({"name": "当前积分", "value": f"{integraltotal}"})
                    integral_task_data = [
                        {
                            "resourceName": "每日签到（积分）",
                            "url": "https://club.mail.wo.cn/clubwebservice/club-user/user-sign/create"
                        },
                        {
                            "irid": 539,
                            "resourceName": "参与俱乐部活动",
                            "resourceFlag": "Web_canyujulebuhuodong+2jifen",
                            "taskState": 0,
                            "scoreNum": 1,
                            "scoreResourceType": "add",
                            "attachData": "{\"jumpLink\":\"/clubwebservice/club-index/activity-scope?currentPage=activityScope\"}",
                            "description": "Web端参与俱乐部活动+1积分"
                        },
                        {
                            "irid": 545,
                            "resourceName": "俱乐部积分兑换",
                            "resourceFlag": "Web_jifenduihuan+2jifen",
                            "taskState": 0,
                            "scoreNum": 1,
                            "scoreResourceType": "add",
                            "attachData": "{\"jumpLink\":\"/clubwebservice/score-exchange/into-score-exchange?currentPage=js-hover\"}",
                            "description": "Web端积分兑换+1积分"
                        }
                    ]
                    lenth = len(integral_task_data)
                    # 执行积分任务
                    for i in range(lenth):
                        resource_name = integral_task_data[i]["resourceName"]
                        try:
                            if "每日签到" in resource_name:
                                url = integral_task_data[i]["url"]
                                res = requests.get(url=url, headers=headers).json()
                                result = res.get("description")
                                if "success" in result:
                                    continuous_day = res["data"]["continuousDay"]
                                    msg.append({"name": resource_name, "value": f"签到成功~已连续签到{str(continuous_day)}天！"})
                                else:
                                    msg.append({"name": resource_name, "value": result})
                            else:
                                resource_flag = integral_task_data[i]["resourceFlag"]
                                resource_flag = resource_flag.replace("+", "%2B")
                                url = f"https://club.mail.wo.cn/clubwebservice/growth/addIntegral?phoneNum={usermobile}&resourceType={resource_flag}"
                                res = requests.get(url=url, headers=headers).json()
                                result = res.get("description")
                                msg.append({"name": resource_name, "value": result})
                        except Exception as e:
                            msg.append({"name": resource_name, "value": str(e)})
                    growthtask_data = [
                        {
                            "resourceName": "每日签到（积分）",
                            "url": "https://club.mail.wo.cn/clubwebservice/club-user/user-sign/create",
                        },
                        {
                            "irid": 254,
                            "resourceName": "参与俱乐部活动",
                            "resourceFlag": "Web_canyujulebuhuodong+2jifen",
                            "taskState": 0,
                            "scoreNum": 1,
                            "scoreResourceType": "add",
                            "attachData": '{"jumpLink":"/clubwebservice/club-index/activity-scope?currentPage=activityScope"}',
                            "description": "Web端参与俱乐部活动+1积分",
                        },
                        {
                            "irid": 561,
                            "resourceName": "俱乐部积分兑换",
                            "resourceFlag": "Web_jifenduihuan+2jifen",
                            "taskState": 0,
                            "scoreNum": 1,
                            "scoreResourceType": "add",
                            "attachData": '{"jumpLink":"/clubwebservice/score-exchange/into-score-exchange?currentPage=js-hover"}',
                            "description": "Web端积分兑换+1积分",
                        },
                    ]
                    lenth = len(growthtask_data)
                    for i in range(lenth):
                        resource_name = growthtask_data[i]["resourceName"]
                        try:
                            if "每日签到" in resource_name:
                                url = growthtask_data[i]["url"]
                                res = requests.get(url=url, headers=headers).json()
                                result = res.get("description")
                                if "success" in result:
                                    continuous_day = res["data"]["continuousDay"]
                                    msg.append({"name": resource_name, "value": f"签到成功~已连续签到{str(continuous_day)}天！"})
                                else:
                                    msg.append({"name": resource_name, "value": result})
                            else:
                                resource_flag = growthtask_data[i]["resourceFlag"]
                                resource_flag = resource_flag.replace("+", "%2B")
                                url = f"https://club.mail.wo.cn/clubwebservice/growth/addGrowthViaTask?phoneNum={usermobile}&resourceType={resource_flag}"
                                res = requests.get(url=url, headers=headers).json()
                                result = res.get("description")
                                msg.append({"name": resource_name, "value": result})
                        except Exception as e:
                            msg.append({"name": resource_name, "value": str(e)})
                except Exception as e:
                    msg.append({"name": "沃邮箱俱乐部", "value": str(e)})
            else:
                msg.append({"name": "沃邮箱俱乐部", "value": "获取 SESSION 失败"})
        except Exception as e:
            print("沃邮箱俱乐部获取 COOKIES 失败", e)
            msg.append({"name": "沃邮箱俱乐部", "value": "获取 COOKIES 失败"})
        return msg

    def dotask3(self, womail_url):
        msg = []
        try:
            dated = int(time.time())
            end_time = time.mktime(time.strptime("2021-10-31 23:59:59", "%Y-%m-%d %H:%M:%S"))  # 设置活动结束日期
            if dated < end_time:
                # 登录账户
                userdata = re.findall("mobile.*", womail_url)[0]
                session = requests.session()
                session.headers = {
                    "User-Agent": "Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.25 Safari/537.36 Core/1.70.3868.400 QQBrowser/10.8.4394.400"
                }
                # 做任务
                url = f"https://nyan.mail.wo.cn/cn/puzzle2/index/index?{userdata}"
                session.get(url)
                task_list = ["checkin", "viewclub", "loginmail"]
                for taskName in task_list:
                    url = f"https://nyan.mail.wo.cn/cn/puzzle2/user/doTask.do?taskName={taskName}"
                    res = session.get(url).json()
                    if res["success"] and res["result"] == 1:
                        msg.append({"name": taskName, "value": "做任务成功"})
                    elif res["success"] and res["result"] == -1:
                        msg.append({"name": taskName, "value": "任务已完成"})
                    else:
                        msg.append({"name": taskName, "value": "做任务失败"})
                    time.sleep(2)
                # 获取拼图个数
                timestamp = int(round(time.time() * 1000))
                url = f"https://nyan.mail.wo.cn/cn/puzzle2/index/userinfo.do?time={timestamp}"
                res = session.post(url).json()
                if res["success"]:
                    puzzle = res["result"]["puzzle"]
                    if puzzle == 6:
                        # 抽奖
                        url = "https://nyan.mail.wo.cn/cn/puzzle2/draw/draw"
                        res = session.get(url).json()
                        if res["success"]:
                            prizeTitle = res["result"]["prizeTitle"]
                            msg.append({"name": "抽奖结果", "value": prizeTitle})
                        else:
                            msg.append({"name": "抽奖结果", "value": res["msg"]})
                    else:
                        msg.append({"name": "抽奖结果", "value": f"当前拼图{puzzle}块，未集齐"})
                else:
                    msg.append({"name": "抽奖结果", "value": f"获取拼图个数失败"})
            else:
                msg.append({"name": "抽奖结果", "value": f"活动已结束，不再执行"})
        except Exception as e:
            msg.append({"name": "抽奖结果", "value": str(e)})
        return msg

    def main(self):
        url = self.check_item.get("url")
        try:
            cookies = self.login(womail_url=url)
            if cookies:
                msg = self.dotask(cookies=cookies)
                msg1 = self.dotask2(womail_url=url)
                msg2 = self.dotask3(womail_url=url)
                msg = msg + msg1 + msg2
            else:
                msg = [{"name": "账号信息", "value": "登录失败"}]
        except Exception as e:
            msg = [{"name": "账号信息", "value": str(e)}]
        msg = "\n".join([f"{one.get('name')}: {one.get('value')}" for one in msg])
        return msg


if __name__ == "__main__":
    with open(os.path.join(os.path.dirname(os.path.dirname(__file__)), "config.json"), "r", encoding="utf-8") as f:
        datas = json.loads(f.read())
    _check_item = datas.get("WOMAIL", [])[0]
    print(WoMail(check_item=_check_item).main())



# -*- coding: utf-8 -*-
import json
import os

import requests

from dailycheckin import CheckIn


class YouDao(CheckIn):
    name = "有道云笔记"

    def __init__(self, check_item):
        self.check_item = check_item

    @staticmethod
    def sign(cookies):
        ad_space = 0
        refresh_cookies_res = requests.get("http://note.youdao.com/login/acc/pe/getsess?product=YNOTE", cookies=cookies)
        cookies = dict(refresh_cookies_res.cookies)
        url = "https://note.youdao.com/yws/api/daupromotion?method=sync"
        res = requests.post(url=url, cookies=cookies)
        if "error" not in res.text:
            checkin_response = requests.post(
                url="https://note.youdao.com/yws/mapi/user?method=checkin", cookies=cookies
            )
            for i in range(3):
                ad_response = requests.post(
                    url="https://note.youdao.com/yws/mapi/user?method=adRandomPrompt", cookies=cookies
                )
                ad_space += ad_response.json().get("space", 0) // 1048576
            if "reward" in res.text:
                sync_space = res.json().get("rewardSpace", 0) // 1048576
                checkin_space = checkin_response.json().get("space", 0) // 1048576
                space = sync_space + checkin_space + ad_space
                youdao_message = "+{0}M".format(space)
            else:
                youdao_message = "获取失败"
        else:
            youdao_message = "Cookie 可能过期"
        return youdao_message

    def main(self):
        youdao_cookie = {item.split("=")[0]: item.split("=")[1] for item in self.check_item.get("cookie").split("; ")}
        try:
            ynote_pers = youdao_cookie.get("YNOTE_PERS", "")
            uid = ynote_pers.split("||")[-2]
        except Exception as e:
            print(f"获取账号信息失败: {e}")
            uid = "未获取到账号信息"
        msg = self.sign(cookies=youdao_cookie)
        msg = [
            {"name": "帐号信息", "value": uid},
            {"name": "获取空间", "value": msg},
        ]
        msg = "\n".join([f"{one.get('name')}: {one.get('value')}" for one in msg])
        return msg


if __name__ == "__main__":
    with open(os.path.join(os.path.dirname(os.path.dirname(__file__)), "config.json"), "r", encoding="utf-8") as f:
        datas = json.loads(f.read())
    _check_item = datas.get("YOUDAO", [])[0]
    print(YouDao(check_item=_check_item).main())



# -*- coding: utf-8 -*-
import base64
import hashlib
import json
import os
import random

import requests
import urllib3
from cryptography.hazmat.backends import default_backend
from cryptography.hazmat.primitives.ciphers import algorithms, Cipher, modes
from requests import utils

from dailycheckin import CheckIn

urllib3.disable_warnings()


class Music163(CheckIn):
    name = "网易云音乐"

    def __init__(self, check_item):
        self.check_item = check_item
        self.headers = {
            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/84.0.4147.89 Safari/537.36",
            "Referer": "http://music.163.com/",
            "Accept-Encoding": "gzip, deflate",
        }

    @staticmethod
    def _encrypt(key, text):
        backend = default_backend()
        cipher = Cipher(algorithms.AES(key.encode("utf8")), modes.CBC(b"0102030405060708"), backend=backend)
        encryptor = cipher.encryptor()
        length = 16
        count = len(text.encode("utf-8"))
        if count % length != 0:
            add = length - (count % length)
        else:
            add = 16
        pad = chr(add)
        text1 = text + (pad * add)
        ciphertext = encryptor.update(text1.encode("utf-8")) + encryptor.finalize()
        crypted_str = str(base64.b64encode(ciphertext), encoding="utf-8")
        return crypted_str

    def encrypt(self, text):
        return {
            "params": self._encrypt("TA3YiYCfY2dDJQgg", self._encrypt("0CoJUm6Qyw8W8jud", text)),
            "encSecKey": "84ca47bca10bad09a6b04c5c927ef077d9b9f1e37098aa3eac6ea70eb59df0aa28b691b7e75e4f1f9831754919ea784c8f74fbfadf2898b0be17849fd656060162857830e241aba44991601f137624094c114ea8d17bce815b0cd4e5b8e2fbaba978c6d1d14dc3d1faf852bdd28818031ccdaaa13a6018e1024e2aae98844210",
        }

    def login(self, session, phone, password):
        login_url = "https://music.163.com/weapi/login/cellphone"
        headers = {
            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/84.0.4147.89 Safari/537.36",
            "Referer": "http://music.163.com/",
            "Accept-Encoding": "gzip, deflate",
            "Cookie": "os=pc; osver=Microsoft-Windows-10-Professional-build-10586-64bit; appver=2.0.3.131777; channel=netease; __remember_me=true;",
        }
        hl = hashlib.md5()
        hl.update(password.encode(encoding="utf-8"))
        md5_password = str(hl.hexdigest())
        login_data = self.encrypt(
            json.dumps({"phone": phone, "countrycode": "86", "password": md5_password, "rememberLogin": "true"})
        )
        res = session.post(url=login_url, data=login_data, headers=headers, verify=False)
        ret = res.json()
        if ret["code"] == 200:
            csrf = requests.utils.dict_from_cookiejar(res.cookies)["__csrf"]
            nickname = ret["profile"]["nickname"]
            level_data = self.get_level(session=session, csrf=csrf, login_data=login_data)
            level = level_data["level"]
            now_play_count = level_data["nowPlayCount"]
            next_play_count = level_data["nextPlayCount"]
            now_login_count = level_data["nowLoginCount"]
            next_login_count = level_data["nextLoginCount"]
            return csrf, nickname, level, now_play_count, next_play_count, now_login_count, next_login_count
        else:
            return False, ret.get("message"), 0, 0, 0

    def sign(self, session):
        sign_url = "https://music.163.com/weapi/point/dailyTask"
        res = session.post(url=sign_url, data=self.encrypt('{"type":0}'), headers=self.headers, verify=False)
        ret = res.json()
        if ret["code"] == 200:
            return "签到成功，经验+ " + str(ret["point"])
        elif ret["code"] == -2:
            return "今天已经签到过了"
        else:
            return "签到失败: " + ret["message"]

    def task(self, session, csrf):
        url = "https://music.163.com/weapi/v6/playlist/detail?csrf_token=" + csrf
        recommend_url = "https://music.163.com/weapi/v1/discovery/recommend/resource"
        music_lists = []
        res = session.post(
            url=recommend_url, data=self.encrypt('{"csrf_token":"' + csrf + '"}'), headers=self.headers, verify=False
        )
        ret = res.json()
        if ret["code"] != 200:
            print("获取推荐歌曲失败: ", str(ret["code"]), ":", ret["message"])
        else:
            lists = ret["recommend"]
            music_lists = [(d["id"]) for d in lists]
        music_id = []
        for m in music_lists:
            res = session.post(
                url=url,
                data=self.encrypt(json.dumps({"id": m, "n": 1000, "csrf_token": csrf})),
                headers=self.headers,
                verify=False,
            )
            ret = json.loads(res.text)
            for i in ret["playlist"]["trackIds"]:
                music_id.append(i["id"])
        post_data = json.dumps(
            {
                "logs": json.dumps(
                    list(
                        map(
                            lambda x: {
                                "action": "play",
                                "json": {
                                    "download": 0,
                                    "end": "playend",
                                    "id": x,
                                    "sourceId": "",
                                    "time": 240,
                                    "type": "song",
                                    "wifi": 0,
                                },
                            },
                            random.sample(music_id, 420 if len(music_id) > 420 else len(music_id)),
                        )
                    )
                )
            }
        )
        res = session.post(url="http://music.163.com/weapi/feedback/weblog", data=self.encrypt(post_data))
        ret = res.json()
        if ret["code"] == 200:
            return "刷听歌量成功"
        else:
            return "刷听歌量失败: " + ret["message"]

    def get_level(self, session, csrf, login_data):
        url = "https://music.163.com/weapi/user/level?csrf_token=" + csrf
        res = session.post(url=url, data=login_data, headers=self.headers)
        ret = json.loads(res.text)
        return ret["data"]

    def main(self):
        phone = self.check_item.get("phone")
        password = self.check_item.get("password")
        session = requests.session()
        csrf, nickname, level, now_play_count, next_play_count, now_login_count, next_login_count = self.login(
            session=session, phone=phone, password=password
        )
        res_sign = ""
        res_task = ""
        if csrf:
            res_sign = self.sign(session=session)
            res_task = self.task(session=session, csrf=csrf)
        msg = [
            {"name": "帐号信息", "value": f"{nickname}"},
            {"name": "当前等级", "value": f"{level}"},
            {"name": "签到信息", "value": f"{res_sign}"},
            {"name": "刷歌信息", "value": f"{res_task}"},
            {"name": "当前听歌", "value": f"{now_play_count}"},
            {"name": "升级听歌", "value": f"{next_play_count - now_play_count}"},
            {"name": "升级天数", "value": f"{next_login_count - now_login_count}"},
        ]
        msg = "\n".join([f"{one.get('name')}: {one.get('value')}" for one in msg])
        return msg


if __name__ == "__main__":
    with open(os.path.join(os.path.dirname(os.path.dirname(__file__)), "config.json"), "r", encoding="utf-8") as f:
        datas = json.loads(f.read())
    _check_item = datas.get("MUSIC163", [])[0]
    print(Music163(check_item=_check_item).main())



# -*- coding: utf-8 -*-
import json
import os
import time

import requests

from dailycheckin import CheckIn


class DuoKan(CheckIn):
    name = "多看阅读"

    def __init__(self, check_item):
        self.check_item = check_item
        self.gift_code_list = [
            "d16ad58199c69518a4afd87b5cf0fe67",
            "828672d6bc39ccd25e1f6ad34e00b86c",
            "f0ccc1bb1cecea673c197b928fb8dbd9",
            "6b86c490d92a138de9a0ae6847781caa",
            "c707047e8b820ba441d29cf87dff341e",
            "82b2c012a956b18cff2388d24f2574a6",
            "87d6b5183a361ee1f6ea8cece1ee83c3",
            "9d42576f7e99c94bb752fde06e6770a5",
            "e58d1f67a82a539d9331baaa3785a943",
            "52c95192ebcb1d0113a748df58a72055",
            "511f33e481fe4504d2637aaf6cbbbaff",
            "6e986f36f4a45cadf61d2f246b27cdc6",
            "f27797a6a1d7fe495b0f4de05f799327",
            "4bd335e899fa665f15eea2f215156321",
            "9355df762183f084473432b5c6900c44",
            "4fb21fb04cbbae9d65556c3958603674",
            "2d02ceb4f1bc916510c7407ce4eca5a5",
            "ef314bf665af0b51294e624244acd7d6",
            "1b441a2ab8e9e7dcf11a55b85931132f",
            "005d2345782ab456e5af167336b70623",
            "51ac508a4d494654035f17f1d646779b",
            "0f6579670f1081f1bcba89dd64645b48",
            "0cd858abe26f0d3db561185fe26bbb75",
            "b5f5fd5b47fd587cb003807e97bed783",
            "6ac9509a5cb799efeb1bb877c505f7e3",
            "b5dd986ffc84762429901ffe633d82a0",
            "f98a436cc2c85943d23d986a8d84c3bd",
            "6fc387f2a17b8564ca212e2b16544cc3",
            "12ead6a62411402378c6311199a0b2ef",
            "7d8dcf31e2e69fcf6bd8af4f48831e92",
            "446c3d0303b0dbd6bc2157844f1222ad",
            "439890227d823ff57bed8ad351fa1b75",
            "645acf3107722ab26b9d3194ecd156ff",
            "afcb41dd9bc54d752c26ace985b49960",
            "1100ab94ccd2e8373af70326c194d8ea",
            "373d73c0c0975cf959eb4c40dc82b27c",
            "2167ac28833149e9ad4ca217bcfa1a62",
            "80547afccc42f34e4c8c4083e00a41a6",
            "b604dda473644bd8157bafdf4ae518dc",
            "15eaa8f727b595d512b82f55364b53b9",
            "8fb656937fd613ccbbcacdc384595b03",
            "dd8410da0b5144ba4aba5a618723b72e",
            "204208386b056a2288e541110bfeeec3",
            "c5b2e7344efd4128bcab5840fa427103",
            "0168601e4335095c502e2e550ca53114",
            "dfa12fe056a8deee35da18613173560f",
            "ed945efdef9c7b2de41249a4fed3945e",
            "b9ece5964ab62d51f8b70ffd35191e9d",
            "f0e0ca4ca0b8afd766821a4922a2873c",
            "5c687b8c6bd641f3f2c0d6aaeceafff6",
            "c983be6420027231d77b748f9d02c1f2",
            "7c53358df8156d979cb6cbb74e15877b",
            "a58058035f73628a7c0847c66c350e88",
            "79dd039ca5cf401993801710f9900d6b",
            "5aff116c2cec01fcc69b389034f456a2",
            "d006927cd9bfd620a6af4f76ee3c4100",
            "410fe62830eeb91ca48be24ffe596364",
            "9d18226ff144a72812d0104ce59fb34e",
            "de439c7f75ca80b1d5b8aba619ee200d",
            "00d1a0479590793294bfdd5c427643aa",
            "d57176b1ce88135243bd501e448b8559",
            "7c500eff681637b97dd526bb11737abb",
            "3e197e47aaac926ccd50c37eb2828311",
            "7db084ea5987f841ad77240bcbb8ce54",
            "cce74f0facc50d47c0dd0e3e2f7435fb",
            "f8bb53fbeb9b2d45db8aca1401817599",
            "5baf7f0f355db11eeb0e936b675cdb82",
            "4478a3354de6bcd7e91b49e28a2b2b3f",
            "66a0338d93af82e956122288b08d2b4b",
            "9f598b2b1c9cd0f2b20e335831cce366",
            "9f4a45fec88b2820653abba179759eb6",
            "41086649c9a39ec977ba42f9ce81f828",
            "06ccca6fd73a6e38f65638ab8abbab76",
            "0cfa0a034a203bb3a22be499e74906f4",
            "c0d1da35a8878b7e4dcdf44bf3cd6b96",
            "f34921e16f6518c1149cc083bd8e1ad7",
            "ed0be3c70075d1d8f1a412f9e59a12e7",
            "eb4d6324bae7db952bd220cb4d57a3de",
            "5ba65d9f8ad735681b594f5092f6ab37",
            "2fa6e0b612962937edb37ed7043923fd",
            "baa8268c7d85d793011c5f5b977f8d4b",
            "f4842a465e4583646abf7df67d8e2915",
            "12c6332c8c9ded3d58d45f2dae7de8da",
            "f56609232205692acf6b6a5d337b0965",
            "3e4eed15387843c668fba53641599d07",
            "d1b9d9ede145b5d426130986245cb66e",
            "2979e43f6ab786f5d68cc262105f3c45",
            "118a18ed578c78f4855b416f8271b29a",
            "9122e158d034f094627c70ed6c3d0c33",
            "dd5413c17253e86cc4247984f3bb77e5",
            "b36bb0124b962efccbb601486665ce9e",
            "6afb3a719f8b0a0b2f744b3dad8b15ab",
            "faf18d64268402ed2975a3f60bc9e651",
            "9f4081944d4ca3fa7b831d7c3b6c289d",
            "367d7a3d77a9f96cbd7903b33c30b61f",
            "605276cf621ff9ba34a99e3675a006f6",
            "a50a734c1a3a749918e20205505ef91d",
            "271ff14ba5edfe89a80a3430227bc11b",
            "3bae338062b4bb3a5087eb13cbcc6efe",
            "9b443d60178a9bcb08bae62c41970abf",
            "a4f6e97741054f3567ab6a7257c63ab1",
            "e06a82cc1f05eda4947e5fa0927d89c5",
            "4fa3b4fc274c283efb02c0a1ddd133e7",
            "4aa59e16a3961ed1ebd12b7f15d79547",
            "f75fe88eaa24fc28ac57d963d8b90f2d",
            "42cbe52b6f74761a5a7a79bf370c30ef",
            "7d4571b5c9710e3b5481330bc7123ecc",
            "fcf2f7ec42086809991de5aed5e7ef0d",
            "bb7de9aaf68a83ac1ddbe75ba913b8af",
            "a9bd964b97e785fffb641edb9b402d3f",
            "6a815be6f537b2351e947ed66f74e209",
            "27ae4e4d71395c6255bf7ea57c496507",
            "2b07f369e90f4fc34ef419d891a2906f",
            "7a2dc8a5b3fc0c7ecddb97ed1ce2c833",
            "e7ad152ef27beb80c5d343f41f885b21",
            "ba21758aed15a3a20a27f63bc0d84626",
            "3820f7b8e1ece2614a11264501b5c93e",
            "c3c41c87e6bf752f5237b4fffa33f08b",
            "ed21086ff6682ab8495ecbfbb697af4a",
            "5a2585ff3524f319dfd1f6b735c9a18d",
            "0e61444507f0a780a1c83b612eb5fb9b",
            "b105aa5c696648c0f7aae9e3933f8fe0",
            "fec8f729e9e1d02248b949ce17674e0c",
            "d3323d5560d15d4bc03575dcd0f53ae9",
            "15fbf9d24dd05d9d64a18a8fd28f4dcc",
            "ac0f3bda53081eee547882b2cdc8b04f",
            "5dd3fadcd4ea6b922e1462431966c2bf",
            "4acb71816dad0ce9a53d8fee301d857c",
            "4c7e173f3a046919587db5b2640896e7",
            "8407dc0459d0b367eaced7e5dfdef8ed",
            "17e02409659223ff4e32cabd9ad352d9",
            "c49edc07086b27769eddb981359f56b2",
            "344822f5d8d53fe9aa7a1c7328cd2c59",
            "92259343c65ac0feab5cb56b2e851783",
            "e1e537b0bd37091c0ba4d5f614af9160",
            "dff1116c175ddaaa20f3985a3d88abc6",
            "3b1131a7c7273aa61cbd71b044e9beca",
            "431aab37ef168c383f078b9244008cee",
            "96c3bb8355d7e3ed7265095374f1c090",
            "c3a7d304cdb307f073bef5003d1b8b78",
            "627d884fc905cc353d0028076e39846b",
            "36ce0d88a6bb2d10e0dc0a697f64df4e",
            "dc8dbd035d42a5d8170976d5f532dab0",
            "01c2665e7ea15bc56cca6d955c2e8ae1",
            "c54ae7eeedc87ac52249684f012d3805",
            "2df9b3b8f21a682b20d9d77669087a7a",
            "fded473150a783586c12692fd57d0825",
            "580499e69f42c0ccba0d1f87a83e41e9",
            "99433cb83f1cd7176b7cdeaa7be49cd8",
            "fbd76e8265547376905b3b6004150064",
            "362768496052ae0dfbe909a9b5c6f54e",
            "4f33581089c90944e5ad950646b17712",
            "bffe93cdfe4b8833190e0a59c779e027",
            "78e042b792c3af7faf7a6ebfedf6af9e",
            "51a59c881726c2887efe9752bd9db715",
            "a46ecf03d3f4038ba3de4ae4ac28170f",
            "48d025f7cc34ac29c21d03b2c1f36449",
            "8c9ceb77d61c20cb96ee652eb7b838c9",
            "47a5882c89671429ae532339b7f333ce",
            "a0b735557416ff3d08d3d8440393061a",
            "976d3b3a8fbdf33d525075a9288455ab",
            "636ca4c1db1c4450431ecd7e10a5e671",
            "8c5cd12180027ee6535a837bd4f0259a",
            "b82315333974c76793b3c7f517fe977c",
            "6143d1f3472cd7cf08e3780918019158",
            "20d032426fd66d49bec4f99579252cfa",
            "398ee715d1dfd058a912bc7768d35f82",
            "1f678678966444fb53d118b8134ceb94",
            "d6641f3ed9444eae2b77ba68d3552f6a",
            "ab2babaa19539895a5285c1ded6de8c6",
            "5bc61d3cd53582b859db9cf04fc7e250",
            "5deb619ed27c2754df4f9c7e3ce16b82",
            "b81a322830fee59c75985626f7e0a8b5",
            "e2313ad53d58e181c5fbaef29e5772c3",
            "70d2aa99ef48b6cf1c0e8c107c0e121d",
            "0633cdb06253a2b11e9a9ca234a3e9c3",
            "bd1cbb9764fba94e8f1c0d1c024487af",
            "301cbdbf26210596f9b22123abff0ca8",
            "1fc2448ee192a1d0806ae1eb6fcc81fe",
            "306247030d0b6442c3ded42e9ca99872",
            "1c8f9a0786a01db1d06989345887967e",
            "256ec3a54aaae719aae88d8f9c7f9b5f",
            "45645896cccec48191916fec482979d9",
            "c3a19c728d6fd39925bd63abe15aa446",
            "15f45c4cd8fd4a6c0a3fae14ccafff47",
            "a082c46b09772739af41f01676e1d0d1",
            "14928418f94f5d35b182001ae0160455",
            "dfbc5bc946c72650adaaf570f11a1e80",
            "8a312e3e30d2e8fd1cf8873c3abe1d8c",
            "ef425403acaabfb2a5b3f6ab0aafce8c",
            "c78d471822dd961a53afe23e6c2dfa61",
            "a40f670d8de3784b54784daf63095d88",
            "49a72ace7fd54d8d0833bb2590db58aa",
            "38e3808d28de73af3578f6d64020e1fc",
            "a8be6ab39263d2edf61acafc60949921",
            "d9c16bf0032800916e948ea26624a253",
            "dbf3a62ff403c3ba94d5ab1e6219f5bc",
            "3a6415de684e2978ce17543d66d523f6",
            "2f69a681ee1ff927df1bdbd5431ced1d",
            "e55c0390872735ec285dad8ebdd939e0",
        ]
        self.code_list = [
            "K7S36GFSZC",
            "A2AMBFHP6C",
            "K5HHKUU14D",
            "J18UK6YYAY",
            "1BJGW140U5",
        ]
        self.headers = {"Content-Type": "application/x-www-form-urlencoded; charset=utf-8"}

    @staticmethod
    def get_data(cookies):
        device_id = cookies.get("device_id")
        t = int(time.time())
        t_device_id = f"{device_id}&{t}"
        c = 0
        for index, one in enumerate(t_device_id):
            c = (c * 131 + ord(one)) % 65536
        data = f"_t={t}&_c={c}"
        return data

    def sign(self, cookies):
        url = "https://www.duokan.com/checkin/v0/checkin"
        data = self.get_data(cookies=cookies)
        response = requests.post(url=url, data=data, cookies=cookies, headers=self.headers)
        result = response.json()
        msg = {"name": "每日签到", "value": result.get("msg")}
        return msg

    def info(self, cookies):
        url = "https://www.duokan.com/store/v0/award/coin/list"
        data = f"sandbox=0&{self.get_data(cookies=cookies)}&withid=1"
        response = requests.post(url=url, data=data, cookies=cookies, headers=self.headers)
        result = response.json()
        msg = []
        if "尚未登录" not in result.get("msg"):
            coin = sum([one.get("coin") for one in result.get("data", {}).get("award")])
            msg.append({"name": "当前书豆", "value": coin})
            msg += [
                {"name": f"{one.get('expire')} 到期", "value": f"{one.get('coin')} 书豆"}
                for one in result.get("data", {}).get("award")
            ]
            return msg
        else:
            return [{"name": "账号异常", "value": "Cookie 失效"}]

    def free(self, cookies):
        url = "https://www.duokan.com/hs/v4/channel/query/2027"
        response = requests.get(url=url, cookies=cookies, headers=self.headers)
        bid = response.json().get("items")[0].get("data").get("book_id")
        data = f"payment_name=BC&ch=VSZUVB&book_id={bid}&price=0&allow_discount=1"
        free_url = "https://www.duokan.com/store/v0/payment/book/create"
        response = requests.post(url=free_url, data=data, cookies=cookies, headers=self.headers)
        result = response.json()
        if "尚未登录" not in result.get("msg"):
            book_title = result.get("book").get("title")
            book_msg = result.get("msg")
            msg = {"name": "今日限免", "value": f"{book_title} · {book_msg}"}
        else:
            msg = {"name": "今日限免", "value": f"Cookie 失效"}
        return msg

    def gift(self, cookies):
        url = "https://www.duokan.com/events/common_task_gift_check"
        data = f"code=KYKJF7LL0G&{self.get_data(cookies=cookies)}&withid=1"
        response = requests.post(url=url, data=data, cookies=cookies, headers=self.headers)
        result = response.json()
        if result.get("chances") == 0:
            msg = {"name": "体验任务", "value": "已经做完啦"}
        elif result.get("chances"):
            num = 0
            for gift_code in self.gift_code_list:
                url = "https://www.duokan.com/events/common_task_gift"
                data = f"code=KYKJF7LL0G&chances=1&sign={gift_code}&{self.get_data(cookies=cookies)}&withid=1"
                response = requests.post(url=url, data=data, cookies=cookies, headers=self.headers)
                result = response.json()
                if result.get("msg") == "成功":
                    num += 30
                    print("体验任务完成啦！豆子 +30")
                else:
                    print(result.get("data"))
            msg = {"name": "体验任务", "value": f"获得 {num} 豆子"}
        else:
            msg = {"name": "体验任务", "value": f"{response.text}"}
        return msg

    def add_draw(self, cookies):
        success_count = 0
        for one in range(6):
            url = "https://www.duokan.com/store/v0/event/chances/add"
            data = f"code=8ulcky4bknbe_f&count=1&{self.get_data(cookies=cookies)}&withid=1"
            response = requests.post(url=url, data=data, cookies=cookies, headers=self.headers)
            result = response.json()
            if result.get("result") == 0:
                success_count += 1
        msg = {"name": "添加抽奖", "value": f"{success_count} 次"}
        return msg

    def draw(self, cookies):
        success_count = 0
        for one in range(6):
            url = "https://www.duokan.com/store/v0/event/drawing"
            data = f"code=8ulcky4bknbe_f&{self.get_data(cookies=cookies)}&withid=1"
            response = requests.post(url=url, data=data, cookies=cookies, headers=self.headers)
            result = response.json()
            if result.get("result") == 0:
                success_count += 1
        msg = {"name": "成功抽奖", "value": f"{success_count} 次"}
        return msg

    def download(self, cookies):
        url = "https://www.duokan.com/events/common_task_gift"
        data = f"code=J18UK6YYAY&chances=17&{self.get_data(cookies=cookies)}&withid=1"
        response = requests.post(url=url, data=data, cookies=cookies, headers=self.headers)
        result = response.json()
        msg = {"name": "下载任务", "value": result.get("msg")}
        return msg

    def task(self, cookies):
        success_count = 0
        url = "https://www.duokan.com/events/tasks_gift"
        for code in self.code_list:
            data = f"code={code}&chances=3&{self.get_data(cookies=cookies)}&withid=1"
            response = requests.post(url=url, data=data, cookies=cookies, headers=self.headers)
            result = response.json()
            if result.get("result") == 0:
                success_count += 1
        msg = {"name": "其他任务", "value": f"完成 {success_count} 个"}
        return msg

    def main(self):
        duokan_cookie = {item.split("=")[0]: item.split("=")[1] for item in self.check_item.get("cookie").split("; ")}
        sign_msg = self.sign(cookies=duokan_cookie)
        free_msg = self.free(cookies=duokan_cookie)
        gift_msg = self.gift(cookies=duokan_cookie)
        add_draw_msg = self.add_draw(cookies=duokan_cookie)
        draw_msg = self.draw(cookies=duokan_cookie)
        download_msg = self.download(cookies=duokan_cookie)
        task_msg = self.task(cookies=duokan_cookie)
        info_msg = self.info(cookies=duokan_cookie)
        msg = [sign_msg, free_msg, gift_msg, add_draw_msg, draw_msg, download_msg, task_msg] + info_msg
        msg = "\n".join([f"{one.get('name')}: {one.get('value')}" for one in msg])
        return msg


if __name__ == "__main__":
    with open(os.path.join(os.path.dirname(os.path.dirname(__file__)), "config.json"), "r", encoding="utf-8") as f:
        datas = json.loads(f.read())
    _check_item = datas.get("DUOKAN", [])[0]
    print(DuoKan(check_item=_check_item).main())



# -*- coding: utf-8 -*-

name_map = {
    "IQIYI_COOKIE_LIST": "IQIYI",
    "VQQ_COOKIE_LIST": "VQQ",
    "MGTV_PARAMS_LIST": "MGTV",
    "KGQQ_COOKIE_LIST": "KGQQ",
    "MUSIC163_ACCOUNT_LIST": "MUSIC163",
    "BILIBILI_COOKIE_LIST": "BILIBILI",
    "YOUDAO_COOKIE_LIST": "YOUDAO",
    "FMAPP_ACCOUNT_LIST": "FMAPP",
    "BAIDU_URL_SUBMIT_LIST": "BAIDU",
    "ONEPLUSBBS_COOKIE_LIST": "ONEPLUSBBS",
    "SMZDM_COOKIE_LIST": "SMZDM",
    "TIEBA_COOKIE_LIST": "TIEBA",
    "V2EX_COOKIE_LIST": "V2EX",
    "WWW2NZZ_COOKIE_LIST": "WWW2NZZ",
    "ACFUN_ACCOUNT_LIST": "ACFUN",
    "MIMOTION_ACCOUNT_LIST": "MIMOTION",
    "CLOUD189_ACCOUNT_LIST": "CLOUD189",
    "POJIE_COOKIE_LIST": "POJIE",
    "MEIZU_COOKIE_LIST": "MEIZU",
    "PICACOMIC_ACCOUNT_LIST": "PICACOMIC",
    "ZHIYOO_COOKIE_LIST": "ZHIYOO",
    "WEIBO_COOKIE_LIST": "WEIBO",
    "DUOKAN_COOKIE_LIST": "DUOKAN",
    "CSDN_COOKIE_LIST": "CSDN",
    "WZYD_DATA_LIST": "WZYD",
    "WOMAIL_URL_LIST": "WOMAIL",
}

change_key_map = {
    "ACFUN_ACCOUNT_LIST": {"acfun_password": "password", "acfun_phone": "phone"},
    "BAIDU_URL_SUBMIT_LIST": {"data_url": "data_url", "submit_url": "submit_url", "times": "times"},
    "BILIBILI_COOKIE_LIST": {
        "bilibili_cookie": "cookie",
        "coin_num": "coin_num",
        "coin_type": "coin_type",
        "silver2coin": "silver2coin",
    },
    "CLOUD189_ACCOUNT_LIST": {"cloud189_password": "password", "cloud189_phone": "phone"},
    "CSDN_COOKIE_LIST": {"csdn_cookie": "cookie"},
    "DUOKAN_COOKIE_LIST": {"duokan_cookie": "cookie"},
    "FMAPP_ACCOUNT_LIST": {
        "fmapp_blackbox": "blackbox",
        "fmapp_cookie": "cookie",
        "fmapp_device_id": "device_id",
        "fmapp_fmversion": "fmversion",
        "fmapp_os": "os",
        "fmapp_token": "token",
        "fmapp_useragent": "useragent",
    },
    "HEYTAP": {"cookie": "cookie", "useragent": "useragent"},
    "IQIYI_COOKIE_LIST": {"iqiyi_cookie": "cookie"},
    "KGQQ_COOKIE_LIST": {"kgqq_cookie": "cookie"},
    "MEIZU_COOKIE_LIST": {"draw_count": "draw_count", "meizu_cookie": "cookie"},
    "MGTV_PARAMS_LIST": {"mgtv_params": "params"},
    "MIMOTION_ACCOUNT_LIST": {
        "mimotion_max_step": "max_step",
        "mimotion_min_step": "min_step",
        "mimotion_password": "password",
        "mimotion_phone": "phone",
    },
    "MUSIC163_ACCOUNT_LIST": {"music163_password": "password", "music163_phone": "phone"},
    "ONEPLUSBBS_COOKIE_LIST": {"oneplusbbs_cookie": "cookie"},
    "PICACOMIC_ACCOUNT_LIST": {"picacomic_email": "email", "picacomic_password": "password"},
    "POJIE_COOKIE_LIST": {"pojie_cookie": "cookie"},
    "SMZDM_COOKIE_LIST": {"smzdm_cookie": "cookie"},
    "TIEBA_COOKIE_LIST": {"tieba_cookie": "cookie"},
    "UNICOM": {"app_id": "app_id", "mobile": "mobile", "password": "password"},
    "V2EX_COOKIE_LIST": {"v2ex_cookie": "cookie", "v2ex_proxy": "proxy"},
    "VQQ_COOKIE_LIST": {"auth_refresh": "auth_refresh", "vqq_cookie": "cookie"},
    "WEIBO_COOKIE_LIST": {"weibo_show_url": "url"},
    "WOMAIL_URL_LIST": {"womail_url": "url"},
    "WWW2NZZ_COOKIE_LIST": {"www2nzz_cookie": "cookie"},
    "WZYD_DATA_LIST": {"wzyd_data": "data"},
    "YOUDAO_COOKIE_LIST": {"youdao_cookie": "cookie"},
    "ZHIYOO_COOKIE_LIST": {"zhiyoo_cookie": "cookie"},
}


def format_data(data):
    flag = False
    new_data = {}
    for key, value in data.items():
        if name_map.get(key):
            flag = True
            if isinstance(value, list):
                for one in value:
                    if isinstance(one, dict):
                        if name_map.get(key) not in new_data.keys():
                            new_data[name_map.get(key)] = []
                        for k2, v2 in change_key_map[key].items():
                            try:
                                one[v2] = one.pop(k2)
                            except Exception as e:
                                print(e)
                        new_data[name_map.get(key)].append(one)
            if not new_data.get(name_map.get(key)):
                new_data[name_map.get(key)] = value
        else:
            new_data[key] = value
    return flag, new_data



# -*- coding: utf-8 -*-
import json
import os
from urllib import parse

import requests
import urllib3

from dailycheckin import CheckIn

urllib3.disable_warnings()


class WeiBo(CheckIn):
    name = "微博"

    def __init__(self, check_item):
        self.check_item = check_item

    @staticmethod
    def sign(token):
        headers = {"User-Agent": "Weibo/52588 (iPhone; iOS 14.5; Scale/3.00)"}
        response = requests.get(
            url=f"https://api.weibo.cn/2/checkin/add?c=iphone&{token}", headers=headers, verify=False
        )
        result = response.json()
        if result.get("status") == 10000:
            msg = [
                {"name": "连续签到", "value": f'{result.get("data").get("continuous")}天'},
                {"name": "本次收益", "value": result.get("data").get("desc")},
            ]
        elif result.get("errno") == 30000:
            msg = [
                {"name": "每日签到", "value": "已签到"},
            ]
        elif result.get("status") == 90005:
            msg = [
                {"name": "每日签到", "value": result.get("msg")},
            ]
        else:
            msg = [
                {"name": "每日签到", "value": "签到失败"},
            ]
        return msg

    @staticmethod
    def card(token):
        headers = {"User-Agent": "Weibo/52588 (iPhone; iOS 14.5; Scale/3.00)"}
        response = requests.get(
            url=f"https://api.weibo.cn/2/!/ug/king_act_home?c=iphone&{token}", headers=headers, verify=False
        )
        result = response.json()
        if result.get("status") == 10000:
            nickname = result.get("data").get("user").get("nickname")
            msg = [
                {"name": "用户昵称", "value": nickname},
                {"name": "每日打卡", "value": f'{result.get("data").get("signin").get("title").split("<")[0]}天'},
                {"name": "积分总计", "value": result.get("data").get("user").get("energy")},
            ]
        else:
            msg = [
                {"name": "每日打卡", "value": "活动过期或失效"},
            ]
        return msg

    @staticmethod
    def pay(token):
        headers = {
            "Accept-Encoding": "gzip, deflate",
            "Connection": "keep-alive",
            "Content-Type": "application/x-www-form-urlencoded",
            "Host": "pay.sc.weibo.com",
            "User-Agent": "Mozilla/5.0 (iPhone; CPU iPhone OS 14_5 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Weibo (iPhone10,1__weibo__11.2.1__iphone__os14.5)",
        }
        data = token + "&lang=zh_CN&wm=3333_2001"
        response = requests.post(
            url=f"https://pay.sc.weibo.com/aj/mobile/home/welfare/signin/do", headers=headers, data=data, verify=False
        )
        try:
            result = response.json()
            if result.get("status") == 1:
                msg = [
                    {"name": "微博钱包", "value": f'{result.get("score")} 积分'},
                ]
            elif result.get("status") == 2:
                msg = [
                    {"name": "微博钱包", "value": f"已签到"},
                ]
                info_response = requests.post(
                    url="https://pay.sc.weibo.com/api/client/sdk/app/balance", headers=headers, data=data
                )
                info_result = info_response.json()
                msg += [
                    {"name": "当前现金", "value": f"{info_result.get('data').get('balance')} 元"},
                ]
            else:
                msg = [
                    {"name": "微博钱包", "value": f"Cookie失效"},
                ]
            return msg
        except Exception as e:
            msg = [
                {"name": "微博钱包", "value": f"Cookie失效"},
            ]
            return msg

    def main(self):
        url = self.check_item.get("url")
        query_dict = dict(parse.parse_qsl(parse.urlsplit(url).query))
        token = "&".join([f"{key}={value}" for key, value in query_dict.items() if key in ["from", "uid", "s", "gsid"]])
        sign_msg = self.sign(token=token)
        card_msg = self.card(token=token)
        pay_msg = self.pay(token=token)
        msg = sign_msg + card_msg + pay_msg
        msg = "\n".join([f"{one.get('name')}: {one.get('value')}" for one in msg])
        return msg


if __name__ == "__main__":
    with open(os.path.join(os.path.dirname(os.path.dirname(__file__)), "config.json"), "r", encoding="utf-8") as f:
        datas = json.loads(f.read())
    _check_item = datas.get("WEIBO", [])[0]
    print(WeiBo(check_item=_check_item).main())



# -*- coding: utf-8 -*-
import pkgutil as _pkgutil


class CheckIn(object):
    name = "Base"


__path__ = _pkgutil.extend_path(__path__, __name__)
for _, _modname, _ in _pkgutil.walk_packages(path=__path__, prefix=__name__ + "."):
    if _modname not in ["dailycheckin.main", "dailycheckin.configs"]:
        __import__(_modname)



# -*- coding: utf-8 -*-
import argparse
import json
import os
import time
from datetime import datetime, timedelta

from dailycheckin.__version__ import __version__
from dailycheckin.configs import checkin_map, get_checkin_info, get_notice_info
from dailycheckin.utils.format_config import format_data
from dailycheckin.utils.message import push_message


def parse_arguments():
    parser = argparse.ArgumentParser()
    parser.add_argument("--include", nargs="+", help="任务执行包含的任务列表")
    parser.add_argument("--exclude", nargs="+", help="任务执行排除的任务列表")
    return parser.parse_args()


def check_config(task_list):
    config_path = None
    config_path_list = []
    for one_path in [
        "/ql/scripts/config.json",
        "config.json",
        "../config.json",
        "./config/config.json",
        "../config/config.json",
        "/config.json",
    ]:
        _config_path = os.path.join(os.getcwd(), one_path)
        if os.path.exists(_config_path):
            config_path = os.path.normpath(_config_path)
            break
        config_path_list.append(os.path.normpath(os.path.dirname(_config_path)))
    if config_path:
        print("使用配置文件路径:", config_path)
        with open(config_path, "r", encoding="utf-8") as f:
            try:
                data = json.load(f)
                flag, _data = format_data(data)
                if flag:
                    print(
                        f"""\n\n当前版本大于 0.2.0 需要对「config.json」配置格式已更新，请按照如下更新步骤进行更新:
  1. 更新 Pypi 到最新版本（>= v0.2.0 版本，如何更新看教程文档）
  2. 手动执行一次签到（请复制本次运行输出的配置覆盖到「config.json」文件后，再重新运行）（记得去 https://json.cn 校验一下）
  3. 更新 新版「config.json」配置后，再次手动运行一次，检测签到是否正常即可
  4. 如果失败，请确定 pypi 版本大于 0.2.0 并根据「配置文档」: https://sitoi.gitee.io/dailycheckin/settings/ 手动更新配置。\n
下方内容即是新版配置内容，全部复制即可（记得去 https://json.cn 校验一下）
{'-' * 100}
{json.dumps(_data, ensure_ascii=False)}
{'-' * 100}\n\n"""
                    )
                    return False, False
            except Exception as e:
                print("Json 格式错误，请务必到 http://www.json.cn 网站检查 config.json 文件格式是否正确！")
                return False, False
        try:
            notice_info = get_notice_info(data=data)
            _check_info = get_checkin_info(data=data)
            check_info = {}
            for one_check, check_tuple in checkin_map.items():
                if one_check in task_list:
                    if _check_info.get(one_check.lower()):
                        for index, check_item in enumerate(_check_info.get(one_check.lower(), [])):
                            if "xxxxxx" not in str(check_item) and "多账号" not in str(check_item):
                                if one_check.lower() not in check_info.keys():
                                    check_info[one_check.lower()] = []
                                check_info[one_check.lower()].append(check_item)
            return notice_info, check_info
        except Exception as e:
            print(e)
            return False, False
    else:
        print("未找到 config.json 配置文件\n请在下方任意目录中添加「config.json」文件:\n" + "\n".join(config_path_list))
        return False, False


def checkin():
    start_time = time.time()
    utc_time = (datetime.utcnow() + timedelta(hours=8)).strftime("%Y-%m-%d %H:%M:%S")
    print(f"当前时间: {utc_time}\n当前版本: {__version__}")
    args = parse_arguments()
    include = args.include
    exclude = args.exclude
    if not include:
        include = list(checkin_map.keys())
    else:
        include = [one for one in include if one in checkin_map.keys()]
    if not exclude:
        exclude = []
    else:
        exclude = [one for one in exclude if one in checkin_map.keys()]
    task_list = list(set(include) - set(exclude))
    notice_info, check_info = check_config(task_list)
    if check_info:
        task_name_str = "\n".join(
            [f"「{checkin_map.get(one.upper())[0]}」账号数 : {len(value)}" for one, value in check_info.items()]
        )
        print(f"\n---------- 本次执行签到任务如下 ----------\n\n{task_name_str}\n\n")
        content_list = []
        for one_check, check_list in check_info.items():
            check_name, check_func = checkin_map.get(one_check.upper())
            print(f"----------开始执行「{check_name}」签到----------")
            for index, check_item in enumerate(check_list):
                try:
                    msg = check_func(check_item).main()
                    content_list.append(f"「{check_name}」\n{msg}")
                    print(f"第 {index + 1} 个账号: ✅✅✅✅✅")
                except Exception as e:
                    content_list.append(f"「{check_name}」\n{e}")
                    print(f"第 {index + 1} 个账号: ❌❌❌❌❌\n{e}")
        print("\n\n")
        content_list.append(
            f"开始时间: {utc_time}\n"
            f"任务用时: {int(time.time() - start_time)} 秒\n"
            f"当前版本: {__version__}\n"
            f"项目地址: https://github.com/Sitoi/dailycheckin"
        )
        push_message(content_list=content_list, notice_info=notice_info)
        return


if __name__ == "__main__":
    checkin()
